@@ -34,6 +34,9 @@
 #include "dapplication.h"
 #include "dblureffectwidget.h"
 
+#include <DGuiApplicationHelper>
+#include <DWindowManagerHelper>
+
 DWIDGET_BEGIN_NAMESPACE
 
 DAbstractDialogPrivate::DAbstractDialogPrivate(DAbstractDialog *qq):
@@ -53,26 +56,46 @@ void DAbstractDialogPrivate::init(bool blurIfPossible)
         handle->setEnableSystemResize(false);
 
         bgBlurWidget = new DBlurEffectWidget(q);
+        bgBlurWidget->setAccessibleName("DAbstractDialogBlurEffectWidget");
         bgBlurWidget->lower();
         bgBlurWidget->setBlendMode(DBlurEffectWidget::BehindWindowBlend);
         bgBlurWidget->setFull(true);
         bgBlurWidget->setMaskColor(DBlurEffectWidget::AutoColor);
         bgBlurWidget->setMaskAlpha(204); // 80%
+
+        if (!DWindowManagerHelper::instance()->hasBlurWindow()
+                && DGuiApplicationHelper::instance()->isTabletEnvironment()) {
+            blurIfPossible = false;
+        }
+
         bgBlurWidget->setBlurEnabled(blurIfPossible);
         q->setAttribute(Qt::WA_TranslucentBackground, blurIfPossible);
-    } else {
+    } else if (qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool()) {
+        handle = new DPlatformWindowHandle(q, q);
         // fix wayland no titlebar
         //q->setWindowFlags(q->windowFlags() | Qt::FramelessWindowHint);
     }
 
     q->resize(DIALOG::DEFAULT_WIDTH, DIALOG::DEFAULT_HEIGHT);
     q->setAttribute(Qt::WA_Resized, false);
+
+    if (DGuiApplicationHelper::isTabletEnvironment()) {
+        if (QScreen *screen = QGuiApplication::primaryScreen()) {
+            q->connect(screen, &QScreen::primaryOrientationChanged, q, [ = ] {
+                q->moveToCenter();
+            });
+        }
+    }
 }
 
 QRect DAbstractDialogPrivate::getParentGeometry() const
 {
     D_QC(DAbstractDialog);
 
+    if (DGuiApplicationHelper::isTabletEnvironment()) {
+        return qApp->primaryScreen()->geometry();
+    }
+
     if (q->parentWidget()) {
         return q->parentWidget()->window()->geometry();
     } else {
@@ -89,86 +112,78 @@ QRect DAbstractDialogPrivate::getParentGeometry() const
 }
 
 /*!
-    \~chinese \class DAbstractDialog
-    \~chinese \brief 可以使用 DAbstractDialog 类创建符合 DDE 风格的对话框窗口。
+    \class Dtk::Widget::DAbstractDialog
+    \inmodule dtkwidget
+    \brief 可以使用 DAbstractDialog 类创建符合 DDE 风格的对话框窗口.
+    \brief Use DAbstractDialog class to create dialog window matched DDE style.
 
-    \~chinese \ingroup dialog-classes
-    \~chinese \ingroup abstractwidgets
+    \ingroup dialog-classes
+    \ingroup abstractwidgets
 
-    \~chinese 对话框是一个用于供用户进行短暂周期的任务交互的顶层窗体。 DDialogs 对话框可以是模态的或非模态的。
-    对话框可以提供一个 \ref return "返回值", 并且对话框可以拥有 \ref default "默认按钮"。
+    对话框是一个用于供用户进行短暂周期的任务交互的顶层窗体。 DDialogs 对话框可以是模态的或非模态的。
+    对话框可以提供一个 return "返回值", 并且对话框可以拥有 default "默认按钮"。
 
-    \~chinese 请注意 DAbstractDialog （以及其他继承自 QDialog 的对话框）对构造时传入的 parent 父组件的行为和其他
+    请注意 DAbstractDialog （以及其他继承自 QDialog 的对话框）对构造时传入的 parent 父组件的行为和其他
     Qt 组件或 DTK 组件不同。一个对话框总是一个顶层控件（top-level widget），但如果它有一个父组件
     则对话框的默认位置将会位于其父组件的正中央，并共用其父控件的任务栏入口。
 
-    \~chinese \section modal 模态对话框
+    \section1 modal 模态对话框
 
-    \~chinese 一个 \b{模态} （modal）对话框可以阻止对模态对话框之外的原可见窗体的操作，如请求用户输入
+    一个 \b{模态} （modal）对话框可以阻止对模态对话框之外的原可见窗体的操作，如请求用户输入
     文件名的对话框或是对应用程序本身进行设置的对话框就常是模态对话框。模态对话框可以是
-    \ref Qt::ApplicationModal "应用模态" 的（默认），也可以是 \ref Qt::WindowModal "窗体模态" 的。
+    Qt::ApplicationModal "应用模态" 的（默认），也可以是 Qt::WindowModal "窗体模态" 的。
 
-    \~chinese 当应用模态对话框出现后，用户必须完成与对话框的交互并关闭对话框才能继续与应用的其他窗体进行交互。
+    当应用模态对话框出现后，用户必须完成与对话框的交互并关闭对话框才能继续与应用的其他窗体进行交互。
     窗体模态对话框则仅仅阻止用户与这个对话框的父窗体进行交互而不影响这个父窗体之外的其他窗体。
 
-    \~chinese 显示模态对话框的常见做法是调用 exec() 。当对话框被用户关闭时， exec() 会提供一个有用的
-    \ref return "返回值" 。通常，需要关闭一个对话框并使其返回期望的值时，我们可以把默认按钮，
+    显示模态对话框的常见做法是调用 exec() 。当对话框被用户关闭时， exec() 会提供一个有用的
+    return "返回值" 。通常，需要关闭一个对话框并使其返回期望的值时，我们可以把默认按钮，
     如 \uicontrol OK 确认按钮连接到 accept() 槽，并把 \uicontrol Cancel 取消按钮连接到
     reject() 槽。当然，也可以调用 done() 槽并传递 \c Accepted 或是 \c Rejected 达到相同目的。
 
-    \~chinese 另一个可行方案是调用 setModal(true) 或 setWindowModality(), 然后调用 show() 。而区别于 exec()
+    另一个可行方案是调用 setModal(true) 或 setWindowModality(), 然后调用 show() 。而区别于 exec()
     的是， show() 将立即交回控制权给调用者。对于类似显示进度条的应用场景，如需限定用户只能与对话框交互（
     比如，允许取消一个执行时间过长的操作），此时 setModal(true) 就很有用处。
 
-    \~chinese \section modeless 非模态对话框
+    \section1 modeless 非模态对话框
 
-    \~chinese 一个 \b{非模态}（modeless）对话框表示其对话框本身的操作和该应用的其他窗口互相独立互不影响。
+    一个 \b{非模态}（modeless）对话框表示其对话框本身的操作和该应用的其他窗口互相独立互不影响。
     例如文字处理程序中的“查找文字”功能通常是非模态的，以便用户同时操作对话框和应用程序窗口。
 
-    \~chinese 非模态对话框通过调用 show() 使其显示, 其会将控制权立即返回给调用者。
+    非模态对话框通过调用 show() 使其显示, 其会将控制权立即返回给调用者。
 
-    \~chinese 如果在隐藏对话框后调用 \ref QWidget::show() "show()" ，对话框将显示在其原本所在的位置。若要记住用户
-    调整对话框位置后的位置，需要在 \ref QWidget::closeEvent() "closeEvent()" 中保存窗体位置并在显示对话框
+    如果在隐藏对话框后调用 QWidget::show() "show()" ，对话框将显示在其原本所在的位置。若要记住用户
+    调整对话框位置后的位置，需要在 QWidget::closeEvent() "closeEvent()" 中保存窗体位置并在显示对话框
     前移动对话框到所保存的位置。
 
-    \~chinese \section default 默认按钮
+    \section2 default 默认按钮
 
-    \~chinese 对话框的 \e 默认 按钮是指当用户直接按下回车（Enter / Return）键时所会被按下的按钮。用以表明用户接受了对话框
+    对话框的 \e 默认 按钮是指当用户直接按下回车（Enter / Return）键时所会被按下的按钮。用以表明用户接受了对话框
     的某些操作并想要关闭对话框。对于 QDialog 可以使用 QPushButton::setDefault(), QPushButton::isDefault()
     和 QPushButton::autoDefault() 来设置或调整一个对话框的默认按钮。
 
-    \~chinese \section escapekey 退出（Escape）键
+    \section2 escapekey 退出（Escape）键
 
-    \~chinese 如果用户在对话框出现后按下了 Esc 键, 将会触发 QDialog::reject() 并导致窗体被关闭。 \ref QCloseEvent "关闭事件"
-    不可以是 \ref QEvent::ignore() "忽略事件" .
+    如果用户在对话框出现后按下了 Esc 键, 将会触发 QDialog::reject() 并导致窗体被关闭。 QCloseEvent "关闭事件"
+    不可以是 QEvent::ignore() "忽略事件" .
 
-    \~chinese \section return 返回值 (模态对话框)
+    \section2 return 返回值 (模态对话框)
 
-    \~chinese 模态对话框通常伴随返回值一同使用。例如用来标识判断用户是按下了 \uicontrol OK 确认按钮 还是 \uicontrol Cancel 取消按钮。
+    模态对话框通常伴随返回值一同使用。例如用来标识判断用户是按下了 \uicontrol OK 确认按钮 还是 \uicontrol Cancel 取消按钮。
     对话框可以通过调用 accept() 或 reject() 槽来关闭， exec() 则会根据实际情况返回 \c Accepted 或 \c Rejected 。
     如果对话框没有被销毁，也可以通过 result() 得到对话框的返回值。
 
-    \~chinese 若要修改对话框的关闭行为，你可以重新实现 accept(), reject() 或 done() 。而 \ref QWidget::closeEvent() "closeEvent()"
+    若要修改对话框的关闭行为，你可以重新实现 accept(), reject() 或 done() 。而 QWidget::closeEvent() "closeEvent()"
     仅当你需要记住对话框位置或是重载标准的关闭行为时才应使用。
 
-    \~chinese \sa DDialog, QDialog
+    \sa DDialog, QDialog
 */
 
 /*!
-    \~english \class DAbstractDialog
-    \~english \brief Use DAbstractDialog class to create dialog window matched DDE style.
-
-    \~english \ingroup dialog-classes
-    \~english \ingroup abstractwidgets
-
-    \~english \sa DAbstractDialog, QDialog
-*/
-
-/**
- * \~english \brief DAbstractDialog::DAbstractDialog constructs a DAbstractDialog instance.
- * \~english \param parent is the parent widget to be used.
- *
- * \~chinese \brief 构造一个 DAbstractDialog 实例
+  \brief DAbstractDialog::DAbstractDialog constructs a DAbstractDialog instance.
+  \a parent is the parent widget to be used.
+  
+  \brief 构造一个 DAbstractDialog 实例
  */
 DAbstractDialog::DAbstractDialog(QWidget *parent) :
     QDialog(parent),
@@ -185,25 +200,25 @@ DAbstractDialog::DAbstractDialog(bool blurIfPossible, QWidget *parent)
 }
 
 /*!
- * \enum DAbstractDialog::DisplayPosition
- *
- * \~english \brief The DisplayPosition enum contains the position options that can be specified by all dialogs.
- * \~chinese \brief DAbstractDialog::DisplayPosition 表示对话框的显示位置。
- *
- * \var DAbstractDialog::DisplayPosition DAbstractDialog::Center
- * \~english display this dialog in the center of the screen
- * \~chinese 在屏幕中央显示对话框。
- *
- * \var DAbstractDialog::DisplayPosition DAbstractDialog::TopRight
- * \~english display this dialog in the top right of the screen
- * \~chinese 在屏幕右上角显示对话框。
+  \enum Dtk::Widget::DAbstractDialog::DisplayPosition
+  
+  \brief The DisplayPosition enum contains the position options that can be specified by all dialogs.
+  \brief DAbstractDialog::DisplayPosition 表示对话框的显示位置。
+  
+  \value Center
+  display this dialog in the center of the screen
+  在屏幕中央显示对话框。
+  
+  \value TopRight
+  display this dialog in the top right of the screen
+  在屏幕右上角显示对话框。
  */
 
-/**
- * \~english \brief DAbstractDialog::displayPosition
- * \~english \return the display position of this dialog.
- *
- * \~chinese \brief 获取对话框显示位置
+/*!
+  \brief DAbstractDialog::displayPosition
+  \return the display position of this dialog.
+  
+  \brief 获取对话框显示位置
  */
 DAbstractDialog::DisplayPosition DAbstractDialog::displayPosition() const
 {
@@ -230,10 +245,10 @@ void DAbstractDialog::setGeometry(const QRect &rect)
     d->mouseMoved = true;
 }
 
-/**
- * \~english \brief DAbstractDialog::moveToCenter moves the dialog to the center of the screen or its parent widget.
- *
- * \~chinese \brief 将对话框移动至屏幕中央或其父控件的中央。
+/*!
+  \brief DAbstractDialog::moveToCenter moves the dialog to the center of the screen or its parent widget.
+  
+  \brief 将对话框移动至屏幕中央或其父控件的中央。
  */
 void DAbstractDialog::moveToCenter()
 {
@@ -242,10 +257,10 @@ void DAbstractDialog::moveToCenter()
     moveToCenterByRect(d->getParentGeometry());
 }
 
-/**
- * \~english \brief DAbstractDialog::moveToTopRight moves the dialog to the top right of the screen or its parent widget.
- *
- * \~chinese \brief 将对话框移动至屏幕右上角或其父控件的右上角。
+/*!
+  \brief DAbstractDialog::moveToTopRight moves the dialog to the top right of the screen or its parent widget.
+  
+  \brief 将对话框移动至屏幕右上角或其父控件的右上角。
  */
 void DAbstractDialog::moveToTopRight()
 {
@@ -254,12 +269,12 @@ void DAbstractDialog::moveToTopRight()
     moveToTopRightByRect(d->getParentGeometry());
 }
 
-/**
- * \~english \brief DAbstractDialog::moveToTopRightByRect moves the dialog to the top right corner of the rect.
- * \~english \param rect is the target rect.
- *
- * \~chinese \brief 移动对话框到给定 \a rect 区域的右上角。
- * \~chinese \param rect 是移动所需要参照的 QRect 位置。
+/*!
+  \brief DAbstractDialog::moveToTopRightByRect moves the dialog to the top right corner of the rect.
+  \a rect is the target rect.
+  
+  \brief 移动对话框到给定 \a rect 区域的右上角。
+  \a rect 是移动所需要参照的 QRect 位置。
  */
 void DAbstractDialog::moveToTopRightByRect(const QRect &rect)
 {
@@ -267,12 +282,12 @@ void DAbstractDialog::moveToTopRightByRect(const QRect &rect)
     QDialog::move(QPoint(x, 0));
 }
 
-/**
- * \~english \brief DAbstractDialog::setDisplayPosition sets the position of the dialog.
- * \~english \param displayPosition is the target position.
- *
- * \~chinese \brief 设置对话框的显示位置。
- * \~chinese \param displayPosition 要显示到的位置
+/*!
+  \brief DAbstractDialog::setDisplayPosition sets the position of the dialog.
+  \a displayPosition is the target position.
+  
+  \brief 设置对话框的显示位置。
+  \a displayPosition 要显示到的位置
  */
 void DAbstractDialog::setDisplayPosition(DAbstractDialog::DisplayPosition displayPosition)
 {
@@ -292,12 +307,12 @@ void DAbstractDialog::setDisplayPosition(DAbstractDialog::DisplayPosition displa
     }
 }
 
-/**
- * \~english \brief DAbstractDialog::moveToCenterByRect moves the dialog to the center of the rect.
- * \~english \param rect is the target rect.
- *
- * \~chinese \brief 移动对话框到给定 \a rect 区域的中央。
- * \~chinese \param rect 是移动对话框要参照的 QRect 区域
+/*!
+  \brief DAbstractDialog::moveToCenterByRect moves the dialog to the center of the rect.
+  \a rect is the target rect.
+  
+  \brief 移动对话框到给定 \a rect 区域的中央。
+  \a rect 是移动对话框要参照的 QRect 区域
  */
 void DAbstractDialog::moveToCenterByRect(const QRect &rect)
 {
@@ -360,7 +375,7 @@ void DAbstractDialog::mouseMoveEvent(QMouseEvent *event)
     QDialog::mouseMoveEvent(event);
 }
 
-/*!\reimp */
+/*! \reimp */
 void DAbstractDialog::resizeEvent(QResizeEvent *event)
 {
     if (event->size().width() >= maximumWidth()) {
