@@ -278,190 +278,200 @@ bool DBlurEffectWidgetPrivate::updateWindowBlurArea(QWidget *topLevelWidget)
 }
 
 /*!
- * \~english \class DBlurEffectWidget
- * \~english \brief The DBlurEffectWidget class provides widget that backgrounds are blurred and semitranslucent.
- *
- * \~english DBlurEffectWidget is QWidget that has blurry background. With different
- * \~english blend mode set, DBlurEffectWidget can do in-window-blend, which means the
- * \~english the widget is blended with the widgets between the top level window and the
- * \~english widget itself, and behind-window-blend, which means the widget is blended with
- * \~english the scene behind the window (with the help of WM).
- *
- * \~english The effect has optional styles can choose from: DBlurEffectWidget::DarkColor, DBlurEffectWidget::LightColor, and
- * \~english DBlurEffectWidget::CustomColor. Usually the first two are sufficient, you can also choose
- * \~english CustomColor and set the color you want by setting DBlurEffectWidget::maskColor.
- *
- * \~english \note DBlurEffectWidget with BehindWindowBlend mode will become opaque if
- * \~english WM supports no X11 composite protocol.
+  \class Dtk::Widget::DBlurEffectWidget
+  \inmodule dtkwidget
+
+  \brief 用于实现主窗口或控件背景的实时模糊效果.
+  \brief The DBlurEffectWidget class provides widget that backgrounds are blurred and semitranslucent.
+  
+  分为主窗口模糊 DBlurEffectWidget::BehindWindowBlend 和控件模糊 DBlurEffectWidget::InWindowBlend DBlurEffectWidget::InWindowBlend
+  这两种不同的模式，主窗口模糊效果依赖于窗口管理器的实现，目前仅支持 deepin-wm 和 kwin，
+  可以使用DWindowManagerHelper::hasBlurWindow 判断当前运行环境中的窗口管理器是否支持
+  模糊特效，使用 DPlatformWindowHandle::setWindowBlurAreaByWM 设置主窗口背景的模糊
+  区域。如果在一个主窗口内同时使用了多个 DBlurEffectWidget 控件，则在更新主窗口模糊区域
+  时会自动将所有控件的区域合并到 QVector<WMBlurArea> 或者 QList<QPainterPath>
+  （如果有任意一个控件设置了 DBlurEffectWidget::radius 属性）中统一设置。
+  控件模糊效果的原理和 DClipEffectWidget 类似，在控件绘制时先使用 QPlatformBackingStore::toImage()
+  获取主窗口上控件对应区域内已经绘制的内容，此时获取的内容为此控件下层控件所绘制的内容，将
+  获得的 QImage 对象使用软件算法进行模糊处理，然后再将模糊之后的图像绘制到控件上。由于实现
+  原理限制，不适用于主窗口为OpenGL绘制模式的窗口（如：QOpenGLWindow ），且控件下面使用
+  OpenGL绘制的内容也生成模糊的效果（如 QOpenGLWidget ）
+
+  DBlurEffectWidget is QWidget that has blurry background. With different
+  blend mode set, DBlurEffectWidget can do in-window-blend, which means the
+  the widget is blended with the widgets between the top level window and the
+  widget itself, and behind-window-blend, which means the widget is blended with
+  the scene behind the window (with the help of WM).
+  
+  The effect has optional styles can choose from: DBlurEffectWidget::DarkColor, DBlurEffectWidget::LightColor, and
+  DBlurEffectWidget::CustomColor. Usually the first two are sufficient, you can also choose
+  CustomColor and set the color you want by setting DBlurEffectWidget::maskColor.
+  
+  \note DBlurEffectWidget with BehindWindowBlend mode will become opaque if
+  WM supports no X11 composite protocol.
  */
 
 /*!
- * \~chinese \class DBlurEffectWidget
- * \~chinese \brief 用于实现主窗口或控件背景的实时模糊效果。
- *
- * \~chinese 分为主窗口模糊 DBlurEffectWidget::BehindWindowBlend 和控件模糊 DBlurEffectWidget::InWindowBlend DBlurEffectWidget::InWindowBlend
- * \~chinese 这两种不同的模式，主窗口模糊效果依赖于窗口管理器的实现，目前仅支持 deepin-wm 和 kwin，
- * \~chinese 可以使用DWindowManagerHelper::hasBlurWindow 判断当前运行环境中的窗口管理器是否支持
- * \~chinese 模糊特效，使用 DPlatformWindowHandle::setWindowBlurAreaByWM 设置主窗口背景的模糊
- * \~chinese 区域。如果在一个主窗口内同时使用了多个 DBlurEffectWidget 控件，则在更新主窗口模糊区域
- * \~chinese 时会自动将所有控件的区域合并到 QVector<WMBlurArea> 或者 QList<QPainterPath>
- * \~chinese （如果有任意一个控件设置了 DBlurEffectWidget::radius 属性）中统一设置。
- * \~chinese 控件模糊效果的原理和 DClipEffectWidget 类似，在控件绘制时先使用 QPlatformBackingStore::toImage()
- * \~chinese 获取主窗口上控件对应区域内已经绘制的内容，此时获取的内容为此控件下层控件所绘制的内容，将
- * \~chinese 获得的 QImage 对象使用软件算法进行模糊处理，然后再将模糊之后的图像绘制到控件上。由于实现
- * \~chinese 原理限制，不适用于主窗口为OpenGL绘制模式的窗口（如：QOpenGLWindow ），且控件下面使用
- * \~chinese OpenGL绘制的内容也生成模糊的效果（如 QOpenGLWidget ）
+  \property DBlurEffectWidget::radius
+  \brief 模糊效果计算时的取样范围，模糊的原理为：将此像素点和周围像素点合成计算得到得到新的值，
+  此属性表示像素点周围 radius 距离的所有像素点参与计算
+  \note 可读可写
+  \note 只在模式为 DBlurEffectWidget::InWindowBlend 时有效
  */
 
 /*!
- * \~chinese \property DBlurEffectWidget::radius
- * \~chinese \brief 模糊效果计算时的取样范围，模糊的原理为：将此像素点和周围像素点合成计算得到得到新的值，
- * \~chinese 此属性表示像素点周围 radius 距离的所有像素点参与计算
- * \~chinese \note 可读可写
- * \~chinese \note 只在模式为 DBlurEffectWidget::InWindowBlend 时有效
+  \property DBlurEffectWidget::mode
+  \brief 所采用的模糊算法，默认值为 \a GaussianBlur
+  \note 可读可写
+  \note 只在模式为 DBlurEffectWidget::InWindowBlend 时有效
  */
 
 /*!
- * \~chinese \property DBlurEffectWidget::mode
- * \~chinese \brief 所采用的模糊算法，默认值为 \a GaussianBlur
- * \~chinese \note 可读可写
- * \~chinese \note 只在模式为 DBlurEffectWidget::InWindowBlend 时有效
+  \property DBlurEffectWidget::blendMode
+  \brief 模糊的应用场景，默认会根据有没有父控件自动判断使用哪种模式
+  \note 可读可写
+  \note 父对象为空时设置模式为 DBlurEffectWidget::InWindowBlend 没有意义
  */
 
 /*!
- * \~chinese \property DBlurEffectWidget::blendMode
- * \~chinese \brief 模糊的应用场景，默认会根据有没有父控件自动判断使用哪种模式
- * \~chinese \note 可读可写
- * \~chinese \note 父对象为空时设置模式为 DBlurEffectWidget::InWindowBlend 没有意义
+  \property DBlurEffectWidget::blurRectXRadius
+  \brief 模糊区域在x轴方向上的圆角半径，默认值为0
+  \note 可读可写
+  \sa DBlurEffectWidget::blurRectYRadius DBlurEffectWidget::setMaskPath QPainterPath::addRoundedRect
  */
 
 /*!
- * \~chinese \property DBlurEffectWidget::blurRectXRadius
- * \~chinese \brief 模糊区域在x轴方向上的圆角半径，默认值为0
- * \~chinese \note 可读可写
- * \~chinese \see DBlurEffectWidget::blurRectYRadius DBlurEffectWidget::setMaskPath QPainterPath::addRoundedRect
+  \property DBlurEffectWidget::blurRectYRadius
+  \brief 模糊区域在y轴方向上的圆角半径，默认值为0
+  \note 可读可写
+  \sa DBlurEffectWidget::blurRectXRadius DBlurEffectWidget::setMaskPath QPainterPath::addRoundedRect
  */
 
 /*!
- * \~chinese \property DBlurEffectWidget::blurRectYRadius
- * \~chinese \brief 模糊区域在y轴方向上的圆角半径，默认值为0
- * \~chinese \note 可读可写
- * \~chinese \see DBlurEffectWidget::blurRectXRadius DBlurEffectWidget::setMaskPath QPainterPath::addRoundedRect
+  \property DBlurEffectWidget::maskColor
+  \brief 画在控件模糊背景之上的颜色，此颜色的alpha通道值会被 \a maskAlpha 属性影响
+  修改此属性会自动将颜色模式设置为 CustomColor，设置后将不能再自动根据窗口管理器是否
+  支持混成和模糊来自动使用最佳的颜色
+  \note 可读可写
+  \sa DBlurEffectWidget::blurRectXRadius DBlurEffectWidget::setMaskColor()
  */
 
 /*!
- * \~chinese \property DBlurEffectWidget::maskColor
- * \~chinese \brief 画在控件模糊背景之上的颜色，此颜色的alpha通道值会被 \a maskAlpha 属性影响
- * \~chinese 修改此属性会自动将颜色模式设置为 CustomColor，设置后将不能再自动根据窗口管理器是否
- * \~chinese 支持混成和模糊来自动使用最佳的颜色
- * \~chinese \note 可读可写
- * \~chinese \see DBlurEffectWidget::blurRectXRadius DBlurEffectWidget::setMaskColor(MaskColorType)
+  \property DBlurEffectWidget::maskAlpha
+  \brief maskColor 的alpha通道值。当前窗口管理器支持混成（窗口背景透明）时默认值为102，否则为204
+  \note 可读可写
+  \sa DBlurEffectWidget::maskColor
  */
 
 /*!
- * \~chinese \property DBlurEffectWidget::maskAlpha
- * \~chinese \brief maskColor 的alpha通道值。当前窗口管理器支持混成（窗口背景透明）时默认值为102，否则为204
- * \~chinese \note 可读可写
- * \~chinese \see DBlurEffectWidget::maskColor DPlatformWindowHandle::hasBlurWindow
+  \property DBlurEffectWidget::full
+  \brief 如果值为true，将模糊此控件所在顶层窗口的整个背景，而无论控件的大小和位置，否则使用控件的位置和大小
+  设置顶层窗口的模糊区域。需要注意的时，当控件本身就是顶层窗口且未设置 blurRectXRadius 和 blurRectYRadius
+  属性的情况下，无论 full 属性的值为多少，都将和值为 true 时的行为保持一致。
+  \note 可读可写
+  \note 此属性不影响蒙版的绘制区域
+  \note 只在模糊的混合模式为 BehindWindowBlend 或 DBlurEffectWidget::InWindowBlend 时生效
+  \sa DBlurEffectWidget::blurRectXRadius DBlurEffectWidget::blurRectYRadius
+  \sa DBlurEffectWidget::maskColor
+  \sa DBlurEffectWidget::blendMode
  */
 
 /*!
- * \~chinese \property DBlurEffectWidget::full
- * \~chinese \brief 如果值为true，将模糊此控件所在顶层窗口的整个背景，而无论控件的大小和位置，否则使用控件的位置和大小
- * \~chinese 设置顶层窗口的模糊区域。需要注意的时，当控件本身就是顶层窗口且未设置 blurRectXRadius 和 blurRectYRadius
- * \~chinese 属性的情况下，无论 full 属性的值为多少，都将和值为 true 时的行为保持一致。
- * \~chinese \note 可读可写
- * \~chinese \note 此属性不影响蒙版的绘制区域
- * \~chinese \note 只在模糊的混合模式为 BehindWindowBlend 或 DBlurEffectWidget::InWindowBlend 时生效
- * \~chinese \see DBlurEffectWidget::blurRectXRadius BlurEffectWidget::blurRectYRadius
- * \~chinese \see DBlurEffectWidget::maskColor
- * \~chinese \see DBlurEffectWidget::blendMode
+  \property DBlurEffectWidget::blurEnabled
+  \brief 如果值为 true 则此控件的模糊设置生效，否则不生效
+  \note 可读可写
  */
 
 /*!
- * \~chinese \property DBlurEffectWidget::blurEnabled
- * \~chinese \brief 如果值为 true 则此控件的模糊设置生效，否则不生效
- * \~chinese \note 可读可写
+  \fn void DBlurEffectWidget::radiusChanged(int radius)
+  \brief 信号会在 \a radius 属性的值改变时被发送
+ */
+/*!
+  \fn void DBlurEffectWidget::modeChanged(BlurMode mode)
+  \brief 信号会在 \a mode 属性的值改变时被发送.
+ */
+/*!
+  \fn void DBlurEffectWidget::blendModeChanged(BlendMode blendMode)
+  \brief 信号会在 \a blendMode 属性的值改变时被发送
+ */
+/*!
+  \fn void DBlurEffectWidget::blurRectXRadiusChanged(int blurRectXRadius)
+  \brief 信号会在 \a blurRectXRadius 属性的值改变时被发送
+ */
+/*!
+  \fn void DBlurEffectWidget::blurRectYRadiusChanged(int blurRectYRadius)
+  \brief 信号会在 \a blurRectYRadius 属性的值改变时被发送
+ */
+/*!
+  \fn void DBlurEffectWidget::maskAlphaChanged(quint8 alpha)
+  \brief 信号会在 \a alpha 属性的值改变时被发送
+  \sa DBlurEffectWidget::maskAlpha
+ */
+/*!
+  \fn void DBlurEffectWidget::maskColorChanged(QColor maskColor)
+  \brief 信号会在 \a maskColor 属性的值改变时被发送
  */
 
 /*!
- * \~chinese \fn DBlurEffectWidget::radiusChanged
- * \~chinese \brief 信号会在 radius 属性的值改变时被发送
- * \~chinese \fn DBlurEffectWidget::modeChanged
- * \~chinese \brief 信号会在 mode 属性的值改变时被发送
- * \~chinese \fn DBlurEffectWidget::blendModeChanged
- * \~chinese \brief 信号会在 blendMode 属性的值改变时被发送
- * \~chinese \fn DBlurEffectWidget::blurRectXRadiusChanged
- * \~chinese \brief 信号会在 blurRectXRadius 属性的值改变时被发送
- * * \~chinese \fn DBlurEffectWidget::blurRectYRadiusChanged
- * \~chinese \brief 信号会在 blurRectYRadius 属性的值改变时被发送
- * \~chinese \fn DBlurEffectWidget::maskAlphaChanged
- * \~chinese \brief 信号会在 maskAlpha 属性的值改变时被发送
- * \~chinese \fn DBlurEffectWidget::maskColorChanged
- * \~chinese \brief 信号会在 maskColor 属性的值改变时被发送
+  \enum Dtk::Widget::DBlurEffectWidget::BlurMode
+  DBlurEffectWidget::BlurMode 模糊算法
+  
+  \value GaussianBlur
+  \l {https://zh.wikipedia.org/wiki/高斯模糊}{高斯模糊算法}
  */
 
 /*!
- * \~chinese \enum DBlurEffectWidget::BlurMode
- * \~chinese DBlurEffectWidget::BlurMode 模糊算法
- *
- * \~chinese \var DBlurEffectWidget::GaussianBlur DBlurEffectWidget::GaussianBlur
- * \~chinese \href{https://zh.wikipedia.org/wiki/高斯模糊,高斯模糊算法}
+  \enum Dtk::Widget::DBlurEffectWidget::BlendMode
+  DBlurEffectWidget::BlendMode 模糊模式
+  \image blur-effect.png
+  
+  \value InWindowBlend
+  以窗口内部控件作为模糊背景
+  
+  \value BehindWindowBlend
+  以外部的其它窗口作为模糊背景
+  
+  \value InWidgetBlend
+  同 DBlurEffectWidget::InWindowBlend，区别是不会自动更新用于模糊的源图片
+  可手动调用 DBlurEffectWidget::updateBlurSourceImage 更新，以此来实现自行控制模糊
+  源图片的更新时机
  */
 
 /*!
- * \~chinese \enum DBlurEffectWidget::BlendMode
- * \~chinese DBlurEffectWidget::BlendMode 模糊模式
- * \~chinese \image html blur-effect.png
- *
- * \~chinese \var DBlurEffectWidget::InWindowBlend DBlurEffectWidget::InWindowBlend
- * \~chinese 以窗口内部控件作为模糊背景
- *
- * \~chinese \var DBlurEffectWidget::BehindWindowBlend DBlurEffectWidget::BehindWindowBlend
- * \~chinese 以外部的其它窗口作为模糊背景
- *
- * * \~chinese \var DBlurEffectWidget::InWidgetBlend DBlurEffectWidget::InWidgetBlend
- * \~chinese 同 DBlurEffectWidget::InWindowBlend，区别是不会自动更新用于模糊的源图片
- * \~chinese 可手动调用 DBlurEffectWidget::updateBlurSourceImage 更新，以此来实现自行控制模糊
- * \~chinese 源图片的更新时机
+  \enum Dtk::Widget::DBlurEffectWidget::MaskColorType
+  DBlurEffectWidget::MaskColorType 内置的几种颜色模式。分为三种情况：
+  \a A：模式为 DBlurEffectWidget::InWindowBlend 或当前窗口管理器支持混成且支持窗口背景模糊
+  \a B：模式为 DBlurEffectWidget::BehindWindowBlend 或 DBlurEffectWidget::InWindowBlend 窗口管理器不支持混成
+  \a C：模式为 DBlurEffectWidget::BehindWindowBlend 或 DBlurEffectWidget::InWindowBlend 窗口管理器不支持模糊
+  \sa DBlurEffectWidget::maskAlpha
+  
+  \value DarkColor
+  深色，三种情况下的值分别为：
+  
+  \a A：color{black,#000000}（alpha通道值为非定值）
+  \a B：color{#373F47,#373F47}
+  \a C：color{rgba(0\,0\,0\,0.8),#CC000000}
+  
+  \value LightColor
+  浅色，三种情况下的值分别为：
+  \a A：color{#FFFFFF,#FFFFFF}（alpha通道值为非定值）
+  \a B：color{#FCFCFC,#FCFCFC}
+  \a C：color{rgba(255\,255\,255\,0.8),#CCFFFFFF}
+  
+  \value AutoColor
+  自动颜色，以当前应用的主题的背景色作为叠加色（alpha通道值为非定值）
+  
+  \value CustomColor
+  自定义颜色，使用 DBlurEffectWidget::setMaskColor 设置的颜色
  */
 
 /*!
- * \~chinese \enum DBlurEffectWidget::MaskColorType
- * \~chinese DBlurEffectWidget::MaskColorType 内置的几种颜色模式。分为三种情况：
- * \~chinese \arg \c A：模式为 DBlurEffectWidget::InWindowBlend 或当前窗口管理器支持混成且支持窗口背景模糊
- * \~chinese \arg \c B：模式为 DBlurEffectWidget::BehindWindowBlend 或 DBlurEffectWidget::InWindowBlend 窗口管理器不支持混成
- * \~chinese \arg \c C：模式为 DBlurEffectWidget::BehindWindowBlend 或 DBlurEffectWidget::InWindowBlend 窗口管理器不支持模糊
- * \~chinese \see DBlurEffectWidget::maskAlpha
- *
- * \~chinese \var DBlurEffectWidget::DarkColor DBlurEffectWidget::DarkColor
- * \~chinese 深色，三种情况下的值分别为：
- *
- * \~chinese \arg \c A：\color{black,#000000}（alpha通道值为非定值）
- * \~chinese \arg \c B：\color{#373F47,#373F47}
- * \~chinese \arg \c C：\color{rgba(0\,0\,0\,0.8),#CC000000}
- *
- * \~chinese \var DBlurEffectWidget::LightColor DBlurEffectWidget::LightColor
- * \~chinese 浅色，三种情况下的值分别为：
- * \~chinese \arg \c A：\color{#FFFFFF,#FFFFFF}（alpha通道值为非定值）
- * \~chinese \arg \c B：\color{#FCFCFC,#FCFCFC}
- * \~chinese \arg \c C：\color{rgba(255\,255\,255\,0.8),#CCFFFFFF}
- *
- * \~chinese \var DBlurEffectWidget::AutoColor DBlurEffectWidget::AutoColor
- * \~chinese 自动颜色，以当前应用的主题的背景色作为叠加色（alpha通道值为非定值）
- *
- * \~chinese \var DBlurEffectWidget::CustomColor DBlurEffectWidget::CustomColor
- * \~chinese 自定义颜色，使用 DBlurEffectWidget::setMaskColor 设置的颜色
- */
+  \brief DBlurEffectWidget::DBlurEffectWidget constructs an instance of DBlurEffectWidget.
+  \brief 和普通控件使用方式一样，可以作为任何控件的子控件。默认会开启 Qt::WA_TranslucentBackground，
+  必须设置控件为背景透明，否则控件所在区域的内容重绘时，在此控件下方的区域不会被下层控件重新绘制
 
-/*!
- * \~english \brief DBlurEffectWidget::DBlurEffectWidget constructs an instance of DBlurEffectWidget.
- * \~english \param parent is passed to QWidget constructor.
- */
-/*!
- * \~chinese \brief 和普通控件使用方式一样，可以作为任何控件的子控件。默认会开启 Qt::WA_TranslucentBackground，
- * \~chinese 必须设置控件为背景透明，否则控件所在区域的内容重绘时，在此控件下方的区域不会被下层控件重新绘制
- * \~chinese \param 当父对象为空时，默认使用 DBlurEffectWidget::BehindWindowBlend 模式，否则使用 DBlurEffectWidget::InWindowBlend 模式
+  \a parent is passed to QWidget constructor.
+  \a parent 当父对象为空时，默认使用 DBlurEffectWidget::BehindWindowBlend 模式，否则使用 DBlurEffectWidget::InWindowBlend 模式
  */
 DBlurEffectWidget::DBlurEffectWidget(QWidget *parent)
     : QWidget(parent)
@@ -509,11 +519,10 @@ DBlurEffectWidget::~DBlurEffectWidget()
 }
 
 /*!
- * \~english \property DBlurEffectWidget::radius
- * \~english \brief This property holds the radius of the blur effect.
- *
- * \~english \note This property has no effect with the DBlurEffectWidget::blendMode set
- * \~english to DBlurEffectWidget::BehindWindowBlend.
+  \brief This property holds the radius of the blur effect.
+  
+  \note This property has no effect with the DBlurEffectWidget::blendMode set
+  to DBlurEffectWidget::BehindWindowBlend.
  */
 int DBlurEffectWidget::radius() const
 {
@@ -523,10 +532,9 @@ int DBlurEffectWidget::radius() const
 }
 
 /*!
- * \~english \property DBlurEffectWidget::mode
- * \~english \brief This property holds which blur algorithm to be used.
- *
- * \~english Currently it only supports DBlurEffectWidget::GaussianBlur.
+  \brief This property holds which blur algorithm to be used.
+  
+  Currently it only supports DBlurEffectWidget::GaussianBlur.
  */
 DBlurEffectWidget::BlurMode DBlurEffectWidget::mode() const
 {
@@ -536,8 +544,7 @@ DBlurEffectWidget::BlurMode DBlurEffectWidget::mode() const
 }
 
 /*!
- * \~english \property DBlurEffectWidget::blendMode
- * \~english \brief This property holds which mode is used to blend the widget and its background scene.
+  \brief This property holds which mode is used to blend the widget and its background scene.
  */
 DBlurEffectWidget::BlendMode DBlurEffectWidget::blendMode() const
 {
@@ -547,13 +554,12 @@ DBlurEffectWidget::BlendMode DBlurEffectWidget::blendMode() const
 }
 
 /*!
- * \~english \property DBlurEffectWidget::blurRectXRadius
- * \~english \brief This property holds the xRadius of the effective background.
- *
- * \~english The xRadius and yRadius specify the radius of the ellipses defining
- * \~english the corners of the effective background.
- *
- * \~english \see DBlurEffectWidget::blurRectYRadius
+  \brief This property holds the xRadius of the effective background.
+  
+  The xRadius and yRadius specify the radius of the ellipses defining
+  the corners of the effective background.
+  
+  \sa DBlurEffectWidget::blurRectYRadius
  */
 int DBlurEffectWidget::blurRectXRadius() const
 {
@@ -563,13 +569,12 @@ int DBlurEffectWidget::blurRectXRadius() const
 }
 
 /*!
- * \~english \property DBlurEffectWidget::blurRectYRadius
- * \~english \brief This property holds the yRadius of the effective background.
- *
- * \~english The xRadius and yRadius specify the radius of the ellipses defining
- * \~english the corners of the effective background.
- *
- * \~english \see DBlurEffectWidget::blurRectXRadius
+  \brief This property holds the yRadius of the effective background.
+  
+  The xRadius and yRadius specify the radius of the ellipses defining
+  the corners of the effective background.
+  
+  \sa DBlurEffectWidget::blurRectXRadius
  */
 int DBlurEffectWidget::blurRectYRadius() const
 {
@@ -579,13 +584,12 @@ int DBlurEffectWidget::blurRectYRadius() const
 }
 
 /*!
- * \~english \property DBlurEffectWidget::maskColor
- * \~english \brief This property holds the background color of this widget.
- *
- * \~english It returns predefined colors if the DBlurEffectWidget::maskColorType is set
- * \~english to DBlurEffectWidget::DarkColor or BlurEffectWidget::LightColor, returns
- * \~english the color set by DBlurEffectWidget::setMaskColor if
- * \~english DBlurEffectWidget::maskColorType is set to BlurEffectWidget::CustomColor.
+  \brief This property holds the background color of this widget.
+  
+  It returns predefined colors if the DBlurEffectWidget::maskColorType is set
+  to DBlurEffectWidget::DarkColor or BlurEffectWidget::LightColor, returns
+  the color set by DBlurEffectWidget::setMaskColor if
+  DBlurEffectWidget::maskColorType is set to BlurEffectWidget::CustomColor.
  */
 QColor DBlurEffectWidget::maskColor() const
 {
@@ -613,14 +617,12 @@ quint8 DBlurEffectWidget::maskAlpha() const {
 }
 
 /*!
- * \~english \brief DBlurEffectWidget::setMaskPath set custom area as the effective background.
- * \~english \param path a QPainterPath to be used as the effectvie background.
- */
-/*!
- * \~chinese \brief 设置模糊区域的路径，当未调用过此接口时，模糊区域为整个控件所占据的空间，此路径坐标原点为控件左上角
- * \~chinese \param path
- * \~chinese \warning 设置自定义路径之后，控件大小改变时不会再自动调整模糊区域大小
- * \~chinese \see DBlurEffectWidget::blurRectXRadius DBlurEffectWidget::blurRectYRadius
+  \brief DBlurEffectWidget::setMaskPath set custom area as the effective background.
+  \brief 设置模糊区域的路径，当未调用过此接口时，模糊区域为整个控件所占据的空间，此路径坐标原点为控件左上角
+
+  \a path a QPainterPath to be used as the effectvie background.
+  \warning 设置自定义路径之后，控件大小改变时不会再自动调整模糊区域大小
+  \sa DBlurEffectWidget::blurRectXRadius DBlurEffectWidget::blurRectYRadius
  */
 void DBlurEffectWidget::setMaskPath(const QPainterPath &path)
 {
@@ -636,11 +638,10 @@ void DBlurEffectWidget::setMaskPath(const QPainterPath &path)
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::setSourceImage
- * \~chinese \param image
- * \~chinese \param autoScale
- * \~chinese \warning
- * \~chinese \see
+  \brief DBlurEffectWidget::setSourceImage
+  \a image
+  \a autoScale
+  \warning
  */
 void DBlurEffectWidget::setSourceImage(const QImage &image, bool autoScale)
 {
@@ -658,8 +659,8 @@ void DBlurEffectWidget::setSourceImage(const QImage &image, bool autoScale)
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::isFull
- * \~chinese \return　true 窗口占据了整个模糊区域,反之为false
+  \brief DBlurEffectWidget::isFull
+  \return　true 窗口占据了整个模糊区域,反之为false
  */
 bool DBlurEffectWidget::isFull() const
 {
@@ -669,8 +670,8 @@ bool DBlurEffectWidget::isFull() const
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::blurEnabled
- * \~chinese \return true 模糊区域可伸缩调整
+  \brief DBlurEffectWidget::blurEnabled
+  \return true 模糊区域可伸缩调整
  */
 bool DBlurEffectWidget::blurEnabled() const
 {
@@ -680,8 +681,8 @@ bool DBlurEffectWidget::blurEnabled() const
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::setRadius
- * \~chinese \param radius　模糊区域的圆角大小　如果设定值和原值不一致会发送信号radiusChanged
+  \brief DBlurEffectWidget::setRadius
+  \a radius　模糊区域的圆角大小　如果设定值和原值不一致会发送信号radiusChanged
  */
 void DBlurEffectWidget::setRadius(int radius)
 {
@@ -700,8 +701,8 @@ void DBlurEffectWidget::setRadius(int radius)
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::setMode
- * \~chinese \param mode 设定模糊算法,默认为高斯模糊算法GaussianBlur
+  \brief DBlurEffectWidget::setMode
+  \a mode 设定模糊算法,默认为高斯模糊算法GaussianBlur
  */
 void DBlurEffectWidget::setMode(DBlurEffectWidget::BlurMode mode)
 {
@@ -717,8 +718,8 @@ void DBlurEffectWidget::setMode(DBlurEffectWidget::BlurMode mode)
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::setBlendMode
- * \~chinese \param blendMode 窗口混合模式，模式设定变化发送blendModeChanged信号
+  \brief DBlurEffectWidget::setBlendMode
+  \a blendMode 窗口混合模式，模式设定变化发送blendModeChanged信号
  */
 void DBlurEffectWidget::setBlendMode(DBlurEffectWidget::BlendMode blendMode)
 {
@@ -756,8 +757,8 @@ void DBlurEffectWidget::setBlendMode(DBlurEffectWidget::BlendMode blendMode)
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::setBlurRectXRadius
- * \~chinese \param blurRectXRadius 模糊区域矩形的X圆角大小
+  \brief DBlurEffectWidget::setBlurRectXRadius
+  \a blurRectXRadius 模糊区域矩形的X圆角大小
  */
 void DBlurEffectWidget::setBlurRectXRadius(int blurRectXRadius)
 {
@@ -775,8 +776,8 @@ void DBlurEffectWidget::setBlurRectXRadius(int blurRectXRadius)
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::setBlurRectYRadius
- * \~chinese \param blurRectYRadius 模糊区域矩形的Y圆角大小
+  \brief DBlurEffectWidget::setBlurRectYRadius
+  \a blurRectYRadius 模糊区域矩形的Y圆角大小
  */
 void DBlurEffectWidget::setBlurRectYRadius(int blurRectYRadius)
 {
@@ -794,8 +795,8 @@ void DBlurEffectWidget::setBlurRectYRadius(int blurRectYRadius)
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::setMaskAlpha
- * \~chinese \param alpha　设置Alpha通道,值变化发送maskAlphaChanged信号
+  \brief DBlurEffectWidget::setMaskAlpha
+  \a alpha　设置Alpha通道,值变化发送maskAlphaChanged信号
  */
 void DBlurEffectWidget::setMaskAlpha(quint8 alpha) {
     D_D(DBlurEffectWidget);
@@ -808,8 +809,8 @@ void DBlurEffectWidget::setMaskAlpha(quint8 alpha) {
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::setMaskColor
- * \~chinese \param maskColor 设定mask的颜色
+  \brief DBlurEffectWidget::setMaskColor
+  \a maskColor 设定mask的颜色
  */
 void DBlurEffectWidget::setMaskColor(QColor maskColor)
 {
@@ -830,8 +831,8 @@ void DBlurEffectWidget::setMaskColor(QColor maskColor)
 }
 
 /*!
- * \~chinese \brief 设置控件的颜色模式，默认值为 \a CustomColor
- * \~chinese \param type
+  \brief 设置控件的颜色模式，默认值为 MaskColorType::CustomColor
+  \a type
  */
 void DBlurEffectWidget::setMaskColor(DBlurEffectWidget::MaskColorType type)
 {
@@ -847,8 +848,8 @@ void DBlurEffectWidget::setMaskColor(DBlurEffectWidget::MaskColorType type)
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::setFull
- * \~chinese \param full 设置时候模糊区域占满整个窗口大小
+  \brief DBlurEffectWidget::setFull
+  \a full 设置时候模糊区域占满整个窗口大小
  */
 void DBlurEffectWidget::setFull(bool full)
 {
@@ -864,8 +865,8 @@ void DBlurEffectWidget::setFull(bool full)
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::setBlurEnabled
- * \~chinese \param blurEnabled 设定模糊区域是否可以伸缩
+  \brief DBlurEffectWidget::setBlurEnabled
+  \a blurEnabled 设定模糊区域是否可以伸缩
  */
 void DBlurEffectWidget::setBlurEnabled(bool blurEnabled)
 {
@@ -887,8 +888,8 @@ inline QRect operator *(const QRect &rect, qreal scale)
 }
 
 /*!
- * \~chinese \brief DBlurEffectWidget::updateBlurSourceImage
- * \~chinese \param ren 设定模糊区域的背景图片
+  \brief DBlurEffectWidget::updateBlurSourceImage
+  \a ren 设定模糊区域的背景图片
  */
 void DBlurEffectWidget::updateBlurSourceImage(const QRegion &ren)
 {
@@ -1010,7 +1011,7 @@ void DBlurEffectWidget::moveEvent(QMoveEvent *event)
     }
 
     if (d->blendMode == DBlurEffectWidget::InWindowBlend
-            || d->blendMode == DBlurEffectWidget::InWindowBlend) {
+            || d->blendMode == DBlurEffectWidget::BehindWindowBlend) {
         d->resetSourceImage();
 
         return QWidget::moveEvent(event);
