@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,22 +11,21 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DBLUREFFECTWIDGET_H
 #define DBLUREFFECTWIDGET_H
 
-#include "dtkwidget_global.h"
-#include "dobject.h"
+#include <dtkwidget_global.h>
+#include <DObject>
 
 #include <QWidget>
 
 DWIDGET_BEGIN_NAMESPACE
 
 class DBlurEffectWidgetPrivate;
-
 class LIBDTKWIDGETSHARED_EXPORT DBlurEffectWidget : public QWidget, public DTK_CORE_NAMESPACE::DObject
 {
     Q_OBJECT
@@ -54,7 +53,8 @@ public:
 
     enum BlendMode {
         InWindowBlend,
-        BehindWindowBlend
+        BehindWindowBlend,
+        InWidgetBlend
     };
 
     Q_ENUMS(BlendMode)
@@ -62,6 +62,7 @@ public:
     enum MaskColorType {
         DarkColor,
         LightColor,
+        AutoColor,
         CustomColor
     };
 
@@ -85,6 +86,7 @@ public:
     quint8 maskAlpha() const;
 
     void setMaskPath(const QPainterPath &path);
+    void setSourceImage(const QImage &image, bool autoScale = true);
 
 public Q_SLOTS:
     void setRadius(int radius);
@@ -99,6 +101,8 @@ public Q_SLOTS:
     void setFull(bool full);
     void setBlurEnabled(bool blurEnabled);
 
+    void updateBlurSourceImage(const QRegion &ren);
+
 Q_SIGNALS:
     void radiusChanged(int radius);
     void modeChanged(BlurMode mode);
@@ -111,6 +115,8 @@ Q_SIGNALS:
     void fullChanged(bool full);
     void blurEnabledChanged(bool blurEnabled);
 
+    void blurSourceImageDirtied();
+
 protected:
     DBlurEffectWidget(DBlurEffectWidgetPrivate &dd, QWidget *parent = 0);
 
@@ -120,9 +126,26 @@ protected:
     void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
     void hideEvent(QHideEvent *event) Q_DECL_OVERRIDE;
     void changeEvent(QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *watched, QEvent *event) override;
 
 private:
     D_DECLARE_PRIVATE(DBlurEffectWidget)
+    friend class DBlurEffectGroup;
+};
+
+class DBlurEffectGroupPrivate;
+class DBlurEffectGroup : public DTK_CORE_NAMESPACE::DObject
+{
+    D_DECLARE_PRIVATE(DBlurEffectGroup)
+public:
+    explicit DBlurEffectGroup();
+    ~DBlurEffectGroup();
+
+    void setSourceImage(QImage image, int blurRadius = 35);
+    void addWidget(DBlurEffectWidget *widget, const QPoint &offset = QPoint(0, 0));
+    void removeWidget(DBlurEffectWidget *widget);
+
+    void paint(QPainter *pa, DBlurEffectWidget *widget) const;
 };
 
 DWIDGET_END_NAMESPACE
