@@ -3,12 +3,10 @@
 
 #include <QObject>
 #include <QWidget>
-#include <QHBoxLayout>
-
-#include "dfloatingmessage.h"
-
-DWIDGET_USE_NAMESPACE
+#include <dtkwidget_global.h>
 
+DWIDGET_BEGIN_NAMESPACE
+class DFloatingMessage;
 class DMessageManager: public QObject
 {
     Q_OBJECT
@@ -27,4 +25,6 @@ protected:
     bool eventFilter(QObject *watched, QEvent *event) override;
 };
 
+DWIDGET_END_NAMESPACE
+
 #endif // DMESSAGEMANAGER_H
