@@ -56,15 +56,19 @@ public:
 };
 
 /*!
- * \~chinese \class DSegmentedHighlight
- * \~chinese \brief DSegmentedHighlight 类代表了 DSegmentedControl 中当前选中（即高亮）的部分。
+  \class Dtk::Widget::DSegmentedHighlight
+  \inmodule dtkwidget
+  \obsolete
+  \brief DSegmentedHighlight 类代表了 DSegmentedControl 中当前选中（即高亮）的部分.
+
+  请使用 Dtk::Widget::DButtonBox 代替。
  */
 
 /*!
- * \~chinese \brief DSegmentedHighlight::DSegmentedHighlight 为 DSegmentedHighlight 类的构造函数。
- * \~chinese \param parent 制定了控件的父控件。
- *
- * \~chinese \note 一般使用者无需使用自己构造 DSegmentedHighlight 对象。
+  \brief DSegmentedHighlight::DSegmentedHighlight 为 DSegmentedHighlight 类的构造函数.
+
+  \a parent 制定了控件的父控件。
+  \note 一般使用者无需使用自己构造 DSegmentedHighlight 对象。
  */
 DSegmentedHighlight::DSegmentedHighlight(QWidget *parent) :
     QToolButton(parent)
@@ -72,36 +76,42 @@ DSegmentedHighlight::DSegmentedHighlight(QWidget *parent) :
 }
 
 /*!
- * \~chinese \class DSegmentedControl
- * \~chinese \brief DSegmentedControl 类提供了一种类似标签页的控件。
- * \~chinese 它由一系列的 Segment 构成，每一个 Segment 可以被设置标题和图标，也可以被选中，
- * \~chinese 它们之间的选中为互斥关系。
- * \~chinese DSegmentedControl 更像是脱离于 QTabWidget 工作的 QTabBar 。
- * \~chinese
- * \~chinese 它可以跟 QStackedLayout 搭配使用，达到切换标签页的功能，例如：
- * \~chinese \image html segmentedcontrol.png
- */
+  \class Dtk::Widget::DSegmentedControl
+  \inmodule dtkwidget
+  \brief DSegmentedControl 类提供了一种类似标签页的控件.
 
-
-/*!
- * \~chinese \fn DSegmentedControl::currentChanged(int index)
- * \~chinese \brief 信号在当前选中（高亮）的 Segment 发生改变时触发。
+  它由一系列的 Segment 构成，每一个 Segment 可以被设置标题和图标，也可以被选中，
+  它们之间的选中为互斥关系。
+  DSegmentedControl 更像是脱离于 QTabWidget 工作的 QTabBar 。
+  
+  它可以跟 QStackedLayout 搭配使用，达到切换标签页的功能，例如：
+  \image segmentedcontrol.png
  */
 
 /*!
- * \~chinese \fn DSegmentedControl::currentTitleChanged(QString title)
- * \~chinese \brief 信号在当前选中（高亮）的 Segment 发生改变时触发。
+  \fn void DSegmentedControl::currentChanged(int index)
+  \brief 信号在当前选中（高亮）的 Segment 发生改变时触发.
+
+  \a index 当前标签的索引.
  */
 
 /*!
- * \~chinese \fn DSegmentedControl::animationDurationChanged(int animationDuration)
- * \~chinese \brief 信号在高亮动画的动画周期发生改变时触发。
+  \fn void DSegmentedControl::currentTitleChanged(QString title)
+  \brief 信号在当前选中（高亮）的 Segment 发生改变时触发.
+
+  \a title 改变的标签标题.
  */
 
+/*!
+  \fn void DSegmentedControl::animationDurationChanged(int animationDuration)
+  \brief 信号在高亮动画的动画周期发生改变时触发.
+
+  \a animationDuration 改变的动画周期.
+ */
 
 /*!
- * \~chinese \brief DSegmentedControl::DSegmentedControl 为 DSegmentedControl 类的构造函数。
- * \~chinese \param parent 制定了控件的父控件。
+  \brief DSegmentedControl::DSegmentedControl 为 DSegmentedControl 类的构造函数。
+  \a parent 制定了控件的父控件。
  */
 DSegmentedControl::DSegmentedControl(QWidget *parent)
     : QWidget(parent)
@@ -123,8 +133,8 @@ DSegmentedControl::DSegmentedControl(QWidget *parent)
 }
 
 /*!
- * \~chinese \property DSegmentedControl::count
- * \~chinese \brief count 属性代表了控件中 Segment 的数量。
+  \property DSegmentedControl::count
+  \brief count 属性代表了控件中 Segment 的数量。
  */
 int DSegmentedControl::count() const
 {
@@ -134,8 +144,8 @@ int DSegmentedControl::count() const
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::highlight 用于获取当前选中（高亮）的 Segment 。
- * \~chinese \return 控件中当前选中（高亮）的 Segmnet 。
+  \brief DSegmentedControl::highlight 用于获取当前选中（高亮）的 Segment 。
+  \return 控件中当前选中（高亮）的 Segmnet 。
  */
 const DSegmentedHighlight *DSegmentedControl::highlight() const
 {
@@ -145,8 +155,8 @@ const DSegmentedHighlight *DSegmentedControl::highlight() const
 }
 
 /*!
- * \~chinese \property DSegmentedControl::currentIndex
- * \~chinese \brief currentIndex 属性指示当前选中 Segment 在所有 Segment 中的位置。
+  \property DSegmentedControl::currentIndex
+  \brief currentIndex 属性指示当前选中 Segment 在所有 Segment 中的位置。
  */
 int DSegmentedControl::currentIndex() const
 {
@@ -156,10 +166,10 @@ int DSegmentedControl::currentIndex() const
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::at 用于获取在特定位置上的 Segment。
- * \~chinese Segment 目前由 QToolButton 充当。
- * \~chinese \param index 为所要获取的 Segment 的索引。
- * \~chinese \return 指定索引位置的 Segment。
+  \brief DSegmentedControl::at 用于获取在特定位置上的 Segment。
+  Segment 目前由 QToolButton 充当。
+  \a index 为所要获取的 Segment 的索引。
+  \return 指定索引位置的 Segment。
  */
 QToolButton *DSegmentedControl::at(int index) const
 {
@@ -169,9 +179,9 @@ QToolButton *DSegmentedControl::at(int index) const
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::getText 用于获取在特定位置上 Segment 的标题。
- * \~chinese \param index 为所要获取的 Segment 的索引。
- * \~chinese \return 指定索引位置上 Segment 的标题。
+  \brief DSegmentedControl::getText 用于获取在特定位置上 Segment 的标题。
+  \a index 为所要获取的 Segment 的索引。
+  \return 指定索引位置上 Segment 的标题。
  */
 QString DSegmentedControl::getText(int index) const
 {
@@ -185,9 +195,9 @@ QString DSegmentedControl::getText(int index) const
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::getIcon 用于获取在特定位置上 Segment 的图标。
- * \~chinese \param index 为所要获取的 Segment 的索引。
- * \~chinese \return 指定索引位置上 Segment 的图标。
+  \brief DSegmentedControl::getIcon 用于获取在特定位置上 Segment 的图标。
+  \a index 为所要获取的 Segment 的索引。
+  \return 指定索引位置上 Segment 的图标。
  */
 QIcon DSegmentedControl::getIcon(int index) const
 {
@@ -195,8 +205,8 @@ QIcon DSegmentedControl::getIcon(int index) const
 }
 
 /*!
- * \~chinese \property DSegmentedControl::animationDuration
- * \~chinese \brief animationDuration 属性用于控制控件中高亮部分移动动画的时间周期。
+  \property DSegmentedControl::animationDuration
+  \brief animationDuration 属性用于控制控件中高亮部分移动动画的时间周期。
  */
 int DSegmentedControl::animationDuration() const
 {
@@ -206,10 +216,10 @@ int DSegmentedControl::animationDuration() const
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::indexByTitle 用于通过 Segment 的标题内容获取
- * \~chinese Segment 的索引。
- * \~chinese \param title 指定 Segment 的标题内容。
- * \~chinese \return 指定 Segment 的索引。
+  \brief DSegmentedControl::indexByTitle 用于通过 Segment 的标题内容获取
+  Segment 的索引。
+  \a title 指定 Segment 的标题内容。
+  \return 指定 Segment 的索引。
  */
 int DSegmentedControl::indexByTitle(const QString &title) const
 {
@@ -226,8 +236,8 @@ int DSegmentedControl::indexByTitle(const QString &title) const
 }
 
 /*!
- * \~chinese \property DSegmentedControl::animationType
- * \~chinese \brief animationType 属性用于控制控件中高亮部分移动动画的动画曲线类型。
+  \property DSegmentedControl::animationType
+  \brief animationType 属性用于控制控件中高亮部分移动动画的动画曲线类型。
  */
 QEasingCurve::Type DSegmentedControl::animationType() const
 {
@@ -237,12 +247,12 @@ QEasingCurve::Type DSegmentedControl::animationType() const
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::addSegmented 为控件添加 Segment，并指定标题。
- * \~chinese \param title 为 Segment 的标题。
- * \~chinese \return 新增加的 Segment 的索引。
- *
- *
- * \sa insertSegmented, removeSegmented
+  \brief DSegmentedControl::addSegmented 为控件添加 Segment，并指定标题。
+  \a title 为 Segment 的标题。
+  \return 新增加的 Segment 的索引。
+  
+  
+  \sa insertSegmented, removeSegmented
  */
 int DSegmentedControl::addSegmented(const QString &title)
 {
@@ -254,12 +264,12 @@ int DSegmentedControl::addSegmented(const QString &title)
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::addSegmented 为控件添加 Segment，并指定标题和图标。
- * \~chinese \param icon 为 Segment 的图标。
- * \~chinese \param title 为 Segment 的标题。
- * \~chinese \return 新增加的 Segment 的索引。
- *
- * \sa insertSegmented, removeSegmented
+  \brief DSegmentedControl::addSegmented 为控件添加 Segment，并指定标题和图标。
+  \a icon 为 Segment 的图标。
+  \a title 为 Segment 的标题。
+  \return 新增加的 Segment 的索引。
+  
+  \sa insertSegmented, removeSegmented
  */
 int DSegmentedControl::addSegmented(const QIcon &icon, const QString &title)
 {
@@ -271,11 +281,11 @@ int DSegmentedControl::addSegmented(const QIcon &icon, const QString &title)
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::addSegmented 添加多个 Segment。
- * \~chinese \param titleList 多个 Segment 的标题列表。
- *
- *
- * \sa insertSegmented, removeSegmented
+  \brief DSegmentedControl::addSegmented 添加多个 Segment。
+  \a titleList 多个 Segment 的标题列表。
+  
+  
+  \sa insertSegmented, removeSegmented
  */
 void DSegmentedControl::addSegmented(const QStringList &titleList)
 {
@@ -285,12 +295,12 @@ void DSegmentedControl::addSegmented(const QStringList &titleList)
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::addSegmented 添加多个 Segment。
- * \~chinese \param titleList 为多个 Segment 的标题列表。
- * \~chinese \param iconList 为多个 Segment 的图标列表。
- *
- *
- * \sa insertSegmented, removeSegmented
+  \brief DSegmentedControl::addSegmented 添加多个 Segment。
+  \a titleList 为多个 Segment 的标题列表。
+  \a iconList 为多个 Segment 的图标列表。
+  
+  
+  \sa insertSegmented, removeSegmented
  */
 void DSegmentedControl::addSegmented(const QList<QIcon> &iconList, const QStringList &titleList)
 {
@@ -300,12 +310,12 @@ void DSegmentedControl::addSegmented(const QList<QIcon> &iconList, const QString
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::insertSegmented 用于在特定位置插入一个新的 Segment。
- * \~chinese \param index 指定要插入 Segment 的位置。
- * \~chinese \param title 指定要插入 Segment 的标题。
- *
- *
- * \sa addSegmented, removeSegmented
+  \brief DSegmentedControl::insertSegmented 用于在特定位置插入一个新的 Segment。
+  \a index 指定要插入 Segment 的位置。
+  \a title 指定要插入 Segment 的标题。
+  
+  
+  \sa addSegmented, removeSegmented
  */
 void DSegmentedControl::insertSegmented(int index, const QString &title)
 {
@@ -313,12 +323,12 @@ void DSegmentedControl::insertSegmented(int index, const QString &title)
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::insertSegmented 用于在特定位置插入一个新的 Segment。
- * \~chinese \param index 指定要插入 Segment 的位置。
- * \~chinese \param title 指定要插入 Segment 的标题。
- *
- *
- * \sa addSegmented, removeSegmented
+  \brief DSegmentedControl::insertSegmented 用于在特定位置插入一个新的 Segment。
+  \a index 指定要插入 Segment 的位置。
+  \a title 指定要插入 Segment 的标题。
+  
+  
+  \sa addSegmented, removeSegmented
  */
 void DSegmentedControl::insertSegmented(int index, const QIcon &icon, const QString &title)
 {
@@ -344,8 +354,8 @@ void DSegmentedControl::insertSegmented(int index, const QIcon &icon, const QStr
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::removeSegmented 用于移除特定位置上的 Segment。
- * \~chinese \param index 指定了要移除的 Segment 的索引。
+  \brief DSegmentedControl::removeSegmented 用于移除特定位置上的 Segment。
+  \a index 指定了要移除的 Segment 的索引。
  */
 void DSegmentedControl::removeSegmented(int index)
 {
@@ -363,7 +373,7 @@ void DSegmentedControl::removeSegmented(int index)
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::clear 清除所有 Segment 。
+  \brief DSegmentedControl::clear 清除所有 Segment 。
  */
 void DSegmentedControl::clear()
 {
@@ -410,9 +420,9 @@ bool DSegmentedControl::setCurrentIndex(int currentIndex)
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::setCurrentIndexByTitle 设置标题为指定标题的 Segment 为当前选中（高亮）的 Segment。
- * \~chinese \param title 为指定的标题。
- * \~chinese \return 是否设置成功， true 为设置成功，否则为 false 。
+  \brief DSegmentedControl::setCurrentIndexByTitle 设置标题为指定标题的 Segment 为当前选中（高亮）的 Segment。
+  \a title 为指定的标题。
+  \return 是否设置成功， true 为设置成功，否则为 false 。
  */
 bool DSegmentedControl::setCurrentIndexByTitle(const QString &title)
 {
@@ -420,9 +430,9 @@ bool DSegmentedControl::setCurrentIndexByTitle(const QString &title)
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::setText 用于给特定位置的 Segment 设置标题。
- * \~chinese \param index 为指定 Segment 的索引。
- * \~chinese \param title 为要设定的标题内容。
+  \brief DSegmentedControl::setText 用于给特定位置的 Segment 设置标题。
+  \a index 为指定 Segment 的索引。
+  \a title 为要设定的标题内容。
  */
 void DSegmentedControl::setText(int index, const QString &title)
 {
@@ -430,9 +440,9 @@ void DSegmentedControl::setText(int index, const QString &title)
 }
 
 /*!
- * \~chinese \brief DSegmentedControl::setIcon 用于给特定位置的 Segment 设置图标。
- * \~chinese \param index 为指定 Segment 的索引。
- * \~chinese \param icon 为要设定的图标。
+  \brief DSegmentedControl::setIcon 用于给特定位置的 Segment 设置图标。
+  \a index 为指定 Segment 的索引。
+  \a icon 为要设定的图标。
  */
 void DSegmentedControl::setIcon(int index, const QIcon &icon)
 {
