@@ -31,6 +31,7 @@
 #include <QDragMoveEvent>
 #include <QTimer>
 #include <QToolTip>
+#include <DApplicationHelper>
 
 #include <private/qtabbar_p.h>
 #define private public
@@ -54,6 +55,48 @@ inline static bool verticalTabs(QTabBar::Shape shape)
            || shape == QTabBar::TriangularEast;
 }
 
+// QBoxLayout::Direction与QTabBar::Shape之间的映射
+inline static QBoxLayout::Direction shapeToDirection (const QTabBar::Shape shape)
+{
+    if (verticalTabs(shape)) {
+        return QBoxLayout::TopToBottom;
+    } else {
+        return QBoxLayout::LeftToRight;
+    }
+}
+
+// 判断是否为横向布局
+static inline bool horz(QBoxLayout::Direction dir)
+{
+    return dir == QBoxLayout::RightToLeft || dir == QBoxLayout::LeftToRight;
+}
+
+// TODO 提取到DStyle
+static inline QColor getColor(const QStyleOption *option, DPalette::ColorType type, const QWidget *w)
+{
+    if (auto s = qobject_cast<DStyle*>(w->style())) {
+        const DPalette &pa = DApplicationHelper::instance()->palette(w, option->palette);
+        return s->generatedBrush(option, pa.brush(type), pa.currentColorGroup(), type).color();
+    }
+    return QColor();
+}
+
+// 获得边框线颜色，与chameleonstyle保持一致，TODO 提取到DStyle
+static inline QColor getTabbarBorderColor(const QStyleOption *opt, const QWidget *w)
+{
+    if (DGuiApplicationHelper::instance()->paletteType() == DGuiApplicationHelper::LightType
+            || (DGuiApplicationHelper::instance()->paletteType() == DGuiApplicationHelper::UnknownType
+                && DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType)) {
+        return getColor(opt, DPalette::FrameBorder, w);
+    } else if (DGuiApplicationHelper::instance()->paletteType() == DGuiApplicationHelper::DarkType
+               || (DGuiApplicationHelper::instance()->paletteType() == DGuiApplicationHelper::UnknownType
+                   && DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType)){
+        return QColor(0, 0, 0, static_cast<int>(0.05 * 255));
+    } else {
+        return getColor(opt, DPalette::FrameBorder, w);
+    }
+}
+
 class DMovableTabWidget : public QWidget
 {
 public:
@@ -103,6 +146,7 @@ public:
         addButton = new DIconButton(DStyle::SP_IncreaseElement, qq);
         addButton->setObjectName("AddButton");
         addButton->setAccessibleName("DTabBarAddButton");
+        addButton->installEventFilter(this);
 
         connect(addButton, &DIconButton::clicked,
                 qq, &DTabBar::tabAddRequested);
@@ -139,21 +183,24 @@ public:
         d->rightB->setFixedSize(0, 0);
         d->rightB->installEventFilter(this);
 
+        qq->installEventFilter(this);
+
         connect(leftScrollButton, &DIconButton::clicked, d->leftB, &QToolButton::click);
         connect(rightScrollButton, &DIconButton::clicked, d->rightB, &QToolButton::click);
 
-        layout = new QHBoxLayout(qq);
+        layout = new QBoxLayout(shapeToDirection(d->shape), qq);
         layout->setMargin(0);
         layout->setSpacing(0);
-        stretch = new QSpacerItem(1, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);
-        leftBtnR = new QSpacerItem(0, 0);
+        layout->setContentsMargins(0, 0, 0, 0);
+
         leftBtnL = new QSpacerItem(0, 0);
+        leftBtnR = new QSpacerItem(0, 0);
         rightBtnL = new QSpacerItem(0, 0);
-        addBtnL = new QSpacerItem(DStyle::pixelMetric(style(), DStyle::PM_ContentsSpacing), 0);
-        addBtnR = new QSpacerItem(DStyle::pixelMetric(style(), DStyle::PM_ContentsSpacing), 0);
+        addBtnL = new QSpacerItem(0, 0);
+        addBtnR = new QSpacerItem(0, 0);
+        stretch = new QSpacerItem(1, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);
 
         layout->addSpacerItem(leftBtnL);
-        layout->setContentsMargins(0, 0, 0, 0);
         layout->addWidget(leftScrollButton);
 
         layout->addSpacerItem(leftBtnR);
@@ -162,13 +209,15 @@ public:
 
         layout->addWidget(rightScrollButton);
         layout->addSpacerItem(addBtnL);
-        layout->addWidget(addButton, Qt::AlignCenter);
+        layout->addWidget(addButton);
 
         layout->addSpacerItem(addBtnR);
         layout->addSpacerItem(stretch);
         d->expanding = false;
 
         qq->setTabLabelAlignment(Qt::AlignCenter);
+        updateTabAlignment();
+
         qq->setFocusProxy(this);
 
         connect(this, &DTabBarPrivate::currentChanged, this, &DTabBarPrivate::onCurrentChanged);
@@ -178,6 +227,56 @@ public:
         connect(this, &DTabBarPrivate::tabBarDoubleClicked, qq, &DTabBar::tabBarDoubleClicked);
     }
 
+    // 刷新占位符弹簧的方向及大小,(当前布局方向、是否为直角风格、滑块是否显示、添加按钮是否显示)
+    void refreshSpacers()
+    {
+        D_Q(DTabBar);
+        const int TabSpacing = DStyle::pixelMetric(style(), DStyle::PM_ContentsSpacing, nullptr) / 2;
+        bool isRectType = q->property("_d_dtk_tabbartab_type").toBool();
+        int ll = 0;
+        int lr = 0;
+        int rl = 0;
+        int al = 0;
+        int ar = 0;
+        if (leftScrollButton->isVisible()) {
+            ll = isRectType ? 6 : TabSpacing;
+            lr = isRectType ? 6 : TabSpacing;
+        }
+
+        /* 右箭头、添加按钮都显示，则右键投左右边距6，添加按钮左右边距10
+         * 右箭头、添加按钮都不显示，则没有边距
+         * 只显示右键，左右边距为6
+         * 只显示添加按钮，左右边距为10
+         */
+        if (rightScrollButton->isVisible()) {
+            rl = isRectType ? 6 : TabSpacing;
+            const int AddButtonLeftMargin = 6;
+            al = AddButtonLeftMargin;
+        }
+        if (addButton->isVisible()) {
+            const int AddButtonLeftMargin = 10;
+            al = AddButtonLeftMargin;
+            const int AddButtonRightMargin = 10;
+            ar = AddButtonRightMargin;
+        }
+
+        // 根据布局方向设置不同弹簧策略
+        if (horz(shapeToDirection(shape()))) {
+            leftBtnL->changeSize(ll, 0);
+            leftBtnR->changeSize(lr, 0);
+            rightBtnL->changeSize(rl, 0);
+            addBtnL->changeSize(al, 0);
+            addBtnR->changeSize(ar, 0);
+        } else {
+            leftBtnL->changeSize(0, ll);
+            leftBtnR->changeSize(0, lr);
+            rightBtnL->changeSize(0, rl);
+            addBtnL->changeSize(0, al);
+            addBtnR->changeSize(0, ar);
+        }
+        layout->invalidate();
+    }
+
     ~DTabBarPrivate() override
     {
         if (stretchIsRemove && stretch) {
@@ -185,6 +284,19 @@ public:
         }
     }
 
+    // 更新布局内的控件的对齐方式
+    void updateTabAlignment()
+    {
+        Qt::Alignment tabAlignment = verticalTabs(shape()) ?
+                    Qt::AlignHCenter : Qt::AlignVCenter;
+
+        for (int i = 0; i < layout->count(); i++) {
+            QLayoutItem *item = layout->itemAt(i);
+            item->setAlignment(tabAlignment);
+        }
+        layout->invalidate();
+    }
+
     void moveTabOffset(int index, int offset)
     {
         QTabBarPrivate *d = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_ptr));
@@ -196,6 +308,38 @@ public:
         update();
     }
 
+    // 直角Tabbar，绘制边框延长线。
+    /*
+        ----      ----
+            xxxxxx
+        ----      ----
+     */
+    void drawDTabbarExtendLine()
+    {
+        D_Q(DTabBar);
+
+        if (!q->property("_d_dtk_tabbartab_type").toBool()) {
+            return;
+        }
+
+        QStyleOptionTabBarBase optTabBase;
+        QTabBarPrivate::initStyleBaseOption(&optTabBase, this, q->size());
+
+        QStylePainter p(q);
+        QStyleOption* opt = &optTabBase;
+        p.setPen(getTabbarBorderColor(opt, this));
+
+        const QRect dtabbarRect = q->rect();
+        const QRect qtabbarRect = this->rect();
+
+        // 不用区分是否竖直，线坐标一致，
+        p.drawLine(dtabbarRect.topLeft(), mapTo(q, qtabbarRect.topLeft()));
+        p.drawLine(dtabbarRect.bottomLeft(), mapTo(q, qtabbarRect.bottomLeft()));
+
+        p.drawLine(mapTo(q, qtabbarRect.topRight()), dtabbarRect.topRight());
+        p.drawLine(mapTo(q, qtabbarRect.bottomRight()), dtabbarRect.bottomRight());
+    }
+
     struct TabBarAnimation : public QVariantAnimation {
         TabBarAnimation(QTabBarPrivate::Tab *t,
                         QTabBarPrivate *_priv,
@@ -295,7 +439,7 @@ public:
 
     DIconButton *leftScrollButton;
     DIconButton *rightScrollButton;
-    QHBoxLayout *layout;
+    QBoxLayout *layout;
     QSpacerItem *stretch;
     QSpacerItem *leftBtnL;
     QSpacerItem *leftBtnR;
@@ -359,7 +503,10 @@ void DTabBarPrivate::setupMovableTab()
 
     int taboverlap = style()->pixelMetric(QStyle::PM_TabBarTabOverlap, 0, this);
     QRect grabRect = tabRect(d->pressedIndex);
-    grabRect.adjust(-taboverlap, 0, taboverlap, 0);
+    if (verticalTabs(shape()))
+        grabRect.adjust(0, -taboverlap, 0, taboverlap);
+    else
+        grabRect.adjust(-taboverlap, 0, taboverlap, 0);
 
     QPixmap grabImage(grabRect.size() * devicePixelRatioF());
     grabImage.setDevicePixelRatio(devicePixelRatioF());
@@ -369,10 +516,15 @@ void DTabBarPrivate::setupMovableTab()
 
     QStyleOptionTab tab;
     initStyleOption(&tab, d->pressedIndex);
-    tab.rect.moveTopLeft(QPoint(taboverlap, 0));
+    tab.position = QStyleOptionTab::OnlyOneTab;
+    if (verticalTabs(shape()))
+        tab.rect.moveTopLeft(QPoint(0, taboverlap));
+    else
+        tab.rect.moveTopLeft(QPoint(taboverlap, 0));
     // 强制让文本居中
     tab.rightButtonSize = QSize();
     q_func()->paintTab(&p, d->pressedIndex, tab);
+    p.end();
 
     reinterpret_cast<DMovableTabWidget*>(d->movingTab)->setPixmap(grabImage);
     d->movingTab->setGeometry(grabRect);
@@ -635,7 +787,7 @@ void DTabBarPrivate::autoScrollTabs(const QPoint &mouse)
 
     QTabBarPrivate *d = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_ptr));
     bool vertical = verticalTabs(d->shape);
-    const QSize &size_hint = this->sizeHint();
+    const QSize &size_hint = this->size();
     int scroll_distance = qMin(50, vertical ? rect.height() / 3 : rect.width() / 3);
 
     int start = 0;
@@ -938,30 +1090,15 @@ static QIcon getArrowIcon(const QStyle *style, Qt::ArrowType type)
 
 bool DTabBarPrivate::eventFilter(QObject *watched, QEvent *event)
 {
-    D_Q(DTabBar);
     QTabBarPrivate *d = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_ptr));
-    bool enabled = q->property("_d_dtk_tabbartab_type").toBool();
+    D_Q(DTabBar);
 
     if (watched == d->leftB) {
         switch (event->type()) {
         case QEvent::Show:
-            if (enabled) {
-                leftBtnL->changeSize(10, 0);
-                leftBtnR->changeSize(10, 0);
-                rightBtnL->changeSize(10, 0);
-                if (!q->visibleAddButton())
-                    addBtnL->changeSize(10, 0);
-            }
             leftScrollButton->show();
             break;
         case QEvent::Hide:
-            if (enabled) {
-                leftBtnR->changeSize(0, 0);
-                leftBtnL->changeSize(0, 0);
-                rightBtnL->changeSize(0, 0);
-                if (!q->visibleAddButton())
-                    addBtnL->changeSize(0, 0);
-            }
             leftScrollButton->hide();
             break;
         case QEvent::EnabledChange:
@@ -995,6 +1132,15 @@ bool DTabBarPrivate::eventFilter(QObject *watched, QEvent *event)
         default:
             break;
         }
+    } else if(watched == q) {
+        if (QEvent::Paint == event->type()) {
+            drawDTabbarExtendLine();
+        }
+    }
+    if (event->type() == QEvent::Show || event->type() == QEvent::Hide) {
+        if (watched == d->leftB || watched == d->rightB || watched == addButton) {
+            refreshSpacers();
+        }
     }
 
     return QTabBar::eventFilter(watched, event);
@@ -1042,13 +1188,15 @@ void DTabBarPrivate::paintEvent(QPaintEvent *e)
 
     QStylePainter p(this);
     int selected = -1;
-//    int cut = -1;
-//    bool rtl = optTabBase.direction == Qt::RightToLeft;
+    int cutLeft = -1;
+    int cutRight = -1;
     bool vertical = verticalTabs(d->shape);
-//    QStyleOptionTab cutTab;
+    QStyleOptionTab cutTabLeft;
+    QStyleOptionTab cutTabRight;
     selected = d->currentIndex;
     if (d->dragInProgress)
         selected = d->pressedIndex;
+    const QRect scrollRect = d->normalizedScrollRect();
 
     for (int i = 0; i < d->tabList.count(); ++i)
          optTabBase.tabBarRect |= tabRect(i);
@@ -1073,13 +1221,20 @@ void DTabBarPrivate::paintEvent(QPaintEvent *e)
         if (!(tab.state & QStyle::State_Enabled)) {
             tab.palette.setCurrentColorGroup(QPalette::Disabled);
         }
+
         // If this tab is partially obscured, make a note of it so that we can pass the information
         // along when we draw the tear.
-//        if (((!vertical && (!rtl && tab.rect.left() < 0)) || (rtl && tab.rect.right() > width()))
-//            || (vertical && tab.rect.top() < 0)) {
-//            cut = i;
-//            cutTab = tab;
-//        }
+        QRect tabRect = d->tabList[i].rect;
+        int tabStart = vertical ? tabRect.top() : tabRect.left();
+        int tabEnd = vertical ? tabRect.bottom() : tabRect.right();
+        if (tabStart < scrollRect.left() + d->scrollOffset) {
+            cutLeft = i;
+            cutTabLeft = tab;
+        } else if (tabEnd > scrollRect.right() + d->scrollOffset) {
+            cutRight = i;
+            cutTabRight = tab;
+        }
+
         // Don't bother drawing a tab if the entire tab is outside of the visible tab bar.
         if ((!vertical && (tab.rect.right() < 0 || tab.rect.left() > width()))
             || (vertical && (tab.rect.bottom() < 0 || tab.rect.top() > height())))
@@ -1090,6 +1245,7 @@ void DTabBarPrivate::paintEvent(QPaintEvent *e)
             continue;
 
         q->paintTab(&p, i, tab);
+//        p.drawControl(QStyle::CE_TabBarTab, tab); // Qt源码写法
 
         if (i == flashTabIndex) {
             p.setOpacity(opacityOnFlash);
@@ -1113,6 +1269,7 @@ void DTabBarPrivate::paintEvent(QPaintEvent *e)
         }
         if (!d->dragInProgress) {
             q->paintTab(&p, selected, tab);
+//            p.drawControl(QStyle::CE_TabBarTab, tab); // Qt源码写法
 
             if (selected == flashTabIndex) {
                 p.setOpacity(opacityOnFlash);
@@ -1121,16 +1278,25 @@ void DTabBarPrivate::paintEvent(QPaintEvent *e)
             }
         } else {
             int taboverlap = style()->pixelMetric(QStyle::PM_TabBarTabOverlap, 0, this);
-            d->movingTab->setGeometry(tab.rect.adjusted(-taboverlap, 0, taboverlap, 0));
+            if (verticalTabs(d->shape))
+                d->movingTab->setGeometry(tab.rect.adjusted(-taboverlap, 0, taboverlap, 0));
+            else
+                d->movingTab->setGeometry(tab.rect.adjusted(-taboverlap, 0, taboverlap, 0));
         }
     }
 
     // Only draw the tear indicator if necessary. Most of the time we don't need too.
-//    if (d->leftB->isVisible() && cut >= 0) {
-//        cutTab.rect = rect();
-//        cutTab.rect = style()->subElementRect(QStyle::SE_TabBarTearIndicator, &cutTab, this);
-//        p.drawPrimitive(QStyle::PE_IndicatorTabTear, cutTab);
-//    }
+    if (d->leftB->isVisible() && cutLeft >= 0) {
+        cutTabLeft.rect = rect();
+        cutTabLeft.rect = style()->subElementRect(QStyle::SE_TabBarTearIndicatorLeft, &cutTabLeft, this);
+        p.drawPrimitive(QStyle::PE_IndicatorTabTearLeft, cutTabLeft);
+    }
+
+    if (d->rightB->isVisible() && cutRight >= 0) {
+        cutTabRight.rect = rect();
+        cutTabRight.rect = style()->subElementRect(QStyle::SE_TabBarTearIndicatorRight, &cutTabRight, this);
+        p.drawPrimitive(QStyle::PE_IndicatorTabTearRight, cutTabRight);
+    }
 }
 
 void DTabBarPrivate::mouseMoveEvent(QMouseEvent *event)
@@ -1347,39 +1513,86 @@ QTabBarPrivate *DTabBarPrivate::dd() const
 }
 
 /*!
- * \~chinese \class DTabBar
- * \~chinese \brief DTabBar 是一个标签栏控件，是在 QTabBar 基础之上进行扩展增强。
- *
- * \~chinese 增加了许多特性，比如：新建按钮，支持向外拖放事件...该控件目前被深度编辑器中所使用。
+  \class Dtk::Widget::DTabBar
+  \inmodule dtkwidget
+  \brief DTabBar 是一个标签栏控件，是在 QTabBar 基础之上进行扩展增强.
+  
+  增加了许多特性，比如：新建按钮，支持向外拖放事件...该控件目前被深度编辑器中所使用。
  */
 
 /*!
- * \~chinese \fn DTabBar::currentChanged()
- * \~chinese \brief 当前索引位置改变
- * \~chinese \fn DTabBar::tabCloseRequested()
- * \~chinese \brief 点击关闭后发出
- * \~chinese \fn DTabBar::tabMoved()
- * \~chinese \brief 索引位置发生变化
- * \~chinese \fn DTabBar::tabIsInserted()
- * \~chinese \brief 新标签已插入
- * \~chinese \fn DTabBar::tabIsRemoved()
- * \~chinese \brief 标签已删除
- * \~chinese \fn DTabBar::tabBarClicked()
- * \~chinese \brief 点击索引标签
- * \~chinese \fn DTabBar::tabBarDoubleClicked()
- * \~chinese \brief 双击索引标签
- * \~chinese \fn DTabBar::tabAddRequested()
- * \~chinese \brief 新标签加入
- * \~chinese \fn DTabBar::tabReleaseRequested()
- * \~chinese \brief 索引标签鼠标释放
- * \~chinese \fn DTabBar::dragActionChanged()
- * \~chinese \brief 鼠标形状发生变化
- * \~chinese \fn DTabBar::tabDroped()
- * \~chinese \brief 标签拖放
- * \~chinese \fn DTabBar::dragStarted()
- * \~chinese \brief 开始拖起
- * \~chinese \fn DTabBar::dragEnd()
- * \~chinese \brief 拖放结束
+  \fn void DTabBar::currentChanged(int index)
+  \brief 当前索引位置改变.
+
+  \a index 改变的索引值.
+ */
+/*!
+  \fn void DTabBar::tabCloseRequested(int index)
+  \brief 点击关闭后发出.
+
+  \a index 关闭的索引值.
+ */
+/*!
+  \fn void DTabBar::tabMoved(int from, int to)
+  \brief 索引位置发生变化
+
+  \a from 索引位置变化的初始值， \a to 位置变化后的索引值.
+ */
+/*!
+  \fn void DTabBar::tabIsInserted(int index)
+  \brief 新标签已插入.
+
+  \a index 被插入标签的索引值.
+ */
+/*!
+  \fn void DTabBar::tabIsRemoved(int index)
+  \brief 标签已删除.
+
+  \a index 被删除标签的索引值.
+ */
+/*!
+  \fn void DTabBar::tabBarClicked(int index)
+  \brief 点击索引标签.
+
+  \a index 点击标签的索引值.
+ */
+/*!
+  \fn void DTabBar::tabBarDoubleClicked(int index)
+  \brief 双击索引标签.
+
+  \a index 双击标记的索引值.
+ */
+/*!
+  \fn void DTabBar::tabAddRequested()
+  \brief 新标签加入.
+ */
+/*!
+  \fn void DTabBar::tabReleaseRequested(int index)
+  \brief 索引标签鼠标释放.
+
+  \a index 标签释放的索引值.
+ */
+/*!
+  \fn void DTabBar::dragActionChanged(Qt::DropAction action)
+  \brief 鼠标形状发生变化.
+
+  \a action 改变的拖拽动作.
+ */
+/*!
+  \fn void DTabBar::tabDroped(int index, Qt::DropAction action, QObject *target)
+  \brief 标签拖放.
+
+  \a index 拖放的标签索引， \a action 拖放的动作, \a target 被拖放的标签 DTabBar 实例
+ */
+/*!
+  \fn void DTabBar::dragStarted()
+  \brief 开始拖起.
+ */
+/*!
+  \fn void DTabBar::dragEnd(Qt::DropAction action)
+  \brief 拖放结束.
+
+  \a action 拖放动作.
  */
 
 DTabBar::DTabBar(QWidget *parent)
@@ -1390,7 +1603,9 @@ DTabBar::DTabBar(QWidget *parent)
 }
 
 /*!
- * \~chinese \brief 设置索引标签的最小尺寸
+  \brief 设置索引标签的最小尺寸.
+
+  \a index 被设置标签的索引值，size ，\a size 最小大小.
  */
 void DTabBar::setTabMinimumSize(int index, const QSize &size)
 {
@@ -1407,7 +1622,9 @@ void DTabBar::setTabMinimumSize(int index, const QSize &size)
 }
 
 /*!
- * \~chinese \brief 设置索引标签的最大尺寸
+  \brief 设置索引标签的最大尺寸.
+
+  \a index 被设置标签的索引值，size ，\a size 最大大小.
  */
 void DTabBar::setTabMaximumSize(int index, const QSize &size)
 {
@@ -1424,7 +1641,9 @@ void DTabBar::setTabMaximumSize(int index, const QSize &size)
 }
 
 /*!
- * \~chinese \brief 新建标签栏按钮是否可见
+  \brief 新建标签栏按钮是否可见.
+
+  \return 新建按钮可见，返回 ture 否则，返回 false 。
  */
 bool DTabBar::visibleAddButton() const
 {
@@ -1434,7 +1653,9 @@ bool DTabBar::visibleAddButton() const
 }
 
 /*!
- * \~chinese \brief 标签栏形状
+  \brief 标签栏形状.
+
+  \return 返回当前 DTabBar 实例的标签栏形状.
  */
 QTabBar::Shape DTabBar::shape() const
 {
@@ -1442,7 +1663,9 @@ QTabBar::Shape DTabBar::shape() const
 }
 
 /*!
- * \~chinese \brief 设置标签栏形状
+  \brief 设置标签栏形状.
+
+  \a shape 标签栏形状.
  */
 void DTabBar::setShape(QTabBar::Shape shape)
 {
@@ -1454,39 +1677,27 @@ void DTabBar::setShape(QTabBar::Shape shape)
     d->setShape(shape);
 
     if (old_vertical != new_vertical) {
-        if (QBoxLayout *layout = qobject_cast<QBoxLayout*>(this->layout())) {
-            if (new_vertical)
-                layout->setDirection(QBoxLayout::TopToBottom);
-            else
-                layout->setDirection(QBoxLayout::LeftToRight);
-        }
-
+        // 设置对应shape上的策略
         if (new_vertical) {
             d->leftScrollButton->setIcon(getArrowIcon(style(), Qt::UpArrow));
             d->rightScrollButton->setIcon(getArrowIcon(style(), Qt::DownArrow));
-            d->leftScrollButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-            d->rightScrollButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-            d->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
-            d->addButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-            d->addButton->setFixedHeight(48);
-            d->addButton->setMinimumWidth(0);
-            d->addButton->setMaximumWidth(9999);
+            d->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
         } else {
             d->leftScrollButton->setIcon(getArrowIcon(style(), Qt::LeftArrow));
             d->rightScrollButton->setIcon(getArrowIcon(style(), Qt::RightArrow));
-            d->leftScrollButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
-            d->rightScrollButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
-            d->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Expanding);
-            d->addButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
-            d->addButton->setFixedWidth(48);
-            d->addButton->setMinimumHeight(0);
-            d->addButton->setMaximumHeight(9999);
+            d->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
         }
+        // 重新设置Direction
+        d->layout->setDirection(shapeToDirection(shape));
+        d->updateTabAlignment();
     }
 }
 
 /*!
- * \~chinese \brief 添加一个新的标签，返回新标签的索引
+  \brief 添加一个新的标签，返回新标签的索引.
+
+  \a text 新标签的标题文本.
+  \return 返回新标签的索引.
  */
 int DTabBar::addTab(const QString &text)
 {
@@ -1494,7 +1705,10 @@ int DTabBar::addTab(const QString &text)
 }
 
 /*!
- * \~chinese \brief 添加一个新的标签，包含图标、文本
+  \brief 添加一个新的标签，包含图标、文本.
+
+  \a icon 新标签的标题图标， \a text 新标签的标题文本.
+  \return 返回新标签的索引.
  */
 int DTabBar::addTab(const QIcon &icon, const QString &text)
 {
@@ -1502,7 +1716,15 @@ int DTabBar::addTab(const QIcon &icon, const QString &text)
 }
 
 /*!
- * \~chinese \brief 插入一个文本标签
+  \brief 插入一个文本标签.
+
+  \a index 被插入的标签索引值， \a text 新标签的标题文本.
+
+  \warning 如果参数 \a index 超过了当前索引，将会在最后添加
+  一个新标签.
+
+  \return 返回插入后的新标签索引.
+  \sa QTabBar::insertTab()
  */
 int DTabBar::insertTab(int index, const QString &text)
 {
@@ -1510,15 +1732,21 @@ int DTabBar::insertTab(int index, const QString &text)
 }
 
 /*!
- * \~chinese \brief 插入一个图标文本标签
+  \brief 插入一个图标文本标签.
+
+  \a index 被插入的标签索引值，\a icon 新标签的图标，\a text 新标签文本
+
+  \return 返回插入后的新标签索引.
  */
 int DTabBar::insertTab(int index, const QIcon &icon, const QString &text)
 {
-    return insertTab(index, icon, text);
+    return d_func()->insertTab(index, icon, text);
 }
 
 /*!
- * \~chinese \brief 移除标签索引位置
+  \brief 移除标签索引位置
+
+  \a index 被移除的标签索引值.
  */
 void DTabBar::removeTab(int index)
 {
@@ -1526,7 +1754,9 @@ void DTabBar::removeTab(int index)
 }
 
 /*!
- * \~chinese \brief 移动标签索引位置
+  \brief 移动标签索引位置
+
+  \a from 被移动前的标签索引，\a to 被移动后的标签索引.
  */
 void DTabBar::moveTab(int from, int to)
 {
@@ -1534,7 +1764,11 @@ void DTabBar::moveTab(int from, int to)
 }
 
 /*!
- * \~chinese \brief 是否启用标签索引位置
+  \brief 是否启用标签索引位置
+
+  \a index 标签索引值.
+
+  \return 启用标签索引返回 true，否则返回 false.
  */
 bool DTabBar::isTabEnabled(int index) const
 {
@@ -1542,7 +1776,9 @@ bool DTabBar::isTabEnabled(int index) const
 }
 
 /*!
- * \~chinese \brief 设置标签索引位置启用状态
+  \brief 设置标签索引位置启用状态
+
+  \a index 标签索引，\a enable 是否启用.
  */
 void DTabBar::setTabEnabled(int index, bool enable)
 {
@@ -1550,7 +1786,10 @@ void DTabBar::setTabEnabled(int index, bool enable)
 }
 
 /*!
- * \~chinese \brief 返回标签索引位置文本
+  \brief 返回标签索引位置文本.
+
+  \a index 标签索引.
+  \return 返回对应索引的文本.
  */
 QString DTabBar::tabText(int index) const
 {
@@ -1558,7 +1797,9 @@ QString DTabBar::tabText(int index) const
 }
 
 /*!
- * \~chinese \brief 设置标签索引位置文本
+  \brief 设置标签索引位置文本.
+
+  \a index 标签索引， \a text 标签文本.
  */
 void DTabBar::setTabText(int index, const QString &text)
 {
@@ -1566,7 +1807,10 @@ void DTabBar::setTabText(int index, const QString &text)
 }
 
 /*!
- * \~chinese \brief 返回标签索引位置图标
+  \brief 返回标签索引位置图标.
+
+  \a index 标签索引.
+  \return 对应标签的图标.
  */
 QIcon DTabBar::tabIcon(int index) const
 {
@@ -1574,7 +1818,9 @@ QIcon DTabBar::tabIcon(int index) const
 }
 
 /*!
- * \~chinese \brief 设置标签索引位置图标
+  \brief 设置标签索引位置图标.
+
+  \a index 标签索引， \a icon 对应的标签图标.
  */
 void DTabBar::setTabIcon(int index, const QIcon &icon)
 {
@@ -1582,7 +1828,9 @@ void DTabBar::setTabIcon(int index, const QIcon &icon)
 }
 
 /*!
- * \~chinese \brief 缩略模式
+  \brief 缩略模式.
+
+  \return 返回标签的文本缩略模式.
  */
 Qt::TextElideMode DTabBar::elideMode() const
 {
@@ -1590,7 +1838,9 @@ Qt::TextElideMode DTabBar::elideMode() const
 }
 
 /*!
- * \~chinese \brief 设置缩略模式
+  \brief 设置缩略模式
+
+  \a mode 文本缩略模式.
  */
 void DTabBar::setElideMode(Qt::TextElideMode mode)
 {
@@ -1600,7 +1850,9 @@ void DTabBar::setElideMode(Qt::TextElideMode mode)
 #ifndef QT_NO_TOOLTIP
 
 /*!
- * \~chinese \brief 设置标签索引位置提示文本
+  \brief 设置标签索引位置提示文本.
+
+  \a index 标签索引, \a tip 提示文本.
  */
 void DTabBar::setTabToolTip(int index, const QString &tip)
 {
@@ -1608,7 +1860,9 @@ void DTabBar::setTabToolTip(int index, const QString &tip)
 }
 
 /*!
- * \~chinese \brief 返回标签索引位置提示文本
+  \brief 返回标签索引位置提示文本.
+
+  \a index 标签索引.
  */
 QString DTabBar::tabToolTip(int index) const
 {
@@ -1629,7 +1883,9 @@ QString DTabBar::tabWhatsThis(int index) const
 #endif
 
 /*!
- * \~chinese \brief 设置标签索引位置数据
+  \brief 设置标签索引位置数据.
+
+  \a index 标签索引, \a data 标签数据.
  */
 void DTabBar::setTabData(int index, const QVariant &data)
 {
@@ -1637,7 +1893,10 @@ void DTabBar::setTabData(int index, const QVariant &data)
 }
 
 /*!
- * \~chinese \brief 返回标签索引位置数据
+  \brief 返回标签索引位置数据.
+
+  \a index 标签索引.
+  \return 标签数据.
  */
 QVariant DTabBar::tabData(int index) const
 {
@@ -1645,7 +1904,10 @@ QVariant DTabBar::tabData(int index) const
 }
 
 /*!
- * \~chinese \brief 返回标签索引位置矩形
+  \brief 返回标签索引位置矩形.
+
+  \a index 标签索引.
+  \return 标签矩形.
  */
 QRect DTabBar::tabRect(int index) const
 {
@@ -1657,7 +1919,10 @@ QRect DTabBar::tabRect(int index) const
 }
 
 /*!
- * \~chinese \brief 根据位置返回标签索引位置
+  \brief 根据位置返回标签索引位置.
+
+  \a pos 对应标签坐标，可以时标签内的任意坐标.
+  \return 返回对应标签的索引值.
  */
 int DTabBar::tabAt(const QPoint &pos) const
 {
@@ -1665,7 +1930,9 @@ int DTabBar::tabAt(const QPoint &pos) const
 }
 
 /*!
- * \~chinese \brief 当前的标签索引位置
+  \brief 当前的标签索引位置.
+
+  \return 当前标签索引.
  */
 int DTabBar::currentIndex() const
 {
@@ -1673,7 +1940,9 @@ int DTabBar::currentIndex() const
 }
 
 /*!
- * \~chinese \brief 标签总数
+  \brief 标签总数.
+
+  \return 返回标签总数.
  */
 int DTabBar::count() const
 {
@@ -1691,7 +1960,9 @@ bool DTabBar::drawBase() const
 }
 
 /*!
- * \~chinese \brief 图标大小
+  \brief 图标大小.
+
+  \return 返回图标大小.
  */
 QSize DTabBar::iconSize() const
 {
@@ -1699,7 +1970,9 @@ QSize DTabBar::iconSize() const
 }
 
 /*!
- * \~chinese \brief 设置图标大小
+  \brief 设置图标大小.
+
+  \a size 图标大小.
  */
 void DTabBar::setIconSize(const QSize &size)
 {
@@ -1717,7 +1990,9 @@ void DTabBar::setUsesScrollButtons(bool useButtons)
 }
 
 /*!
- * \~chinese \brief 标签栏是否可关闭
+  \brief 标签栏是否可关闭.
+
+  \return 返回标签是否可关闭.
  */
 bool DTabBar::tabsClosable() const
 {
@@ -1725,7 +2000,9 @@ bool DTabBar::tabsClosable() const
 }
 
 /*!
- * \~chinese \brief 设置标签栏是否可关闭
+  \brief 设置标签栏是否可关闭.
+
+  \a closable 标签是否可关闭.
  */
 void DTabBar::setTabsClosable(bool closable)
 {
@@ -1754,8 +2031,7 @@ void DTabBar::setSelectionBehaviorOnRemove(QTabBar::SelectionBehavior behavior)
 
 bool DTabBar::expanding() const
 {
-    QTabBarPrivate *dd = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_func()->d_ptr));
-    return dd->expanding;
+    return d_func()->expanding();
 }
 
 void DTabBar::setExpanding(bool enabled)
@@ -1766,7 +2042,7 @@ void DTabBar::setExpanding(bool enabled)
         return;
     QTabBarPrivate *dd = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d->d_ptr));
     dd->expanding = enabled;
-    QHBoxLayout *auto_layout = d->layout;
+    auto auto_layout = d->layout;
 
     if (enabled) {
         auto_layout->removeItem(d->stretch);
@@ -1855,38 +2131,41 @@ QWindow *DTabBar::dragIconWindow() const
 }
 
 /*!
- * \~chinese \brief DTabBar::setEnabledEmbedStyle 启用直角样式的Tabbar
- * \~chinese \row 此风格适用于切换窗口的操作,多用于支持多开的应用
- * \param replace true 启用，false 恢复
+  \brief 启用直角样式的 Tabbar.
+
+  此风格适用于切换窗口的操作,多用于支持多开的应用.
+
+  \a enable true 启用，false 恢复
  */
 void DTabBar::setEnabledEmbedStyle(bool enable)
 {
     D_D(DTabBar);
 
-    int radius;
     setProperty("_d_dtk_tabbartab_type", enable);
 
+    int radius;
+    QSize size;
     if (enable) {
         radius = DStyle::pixelMetric(style(), DStyle::PM_FloatingWidgetRadius);
-        d->addButton->setMaximumSize(QSize(24, 24));
-        d->rightScrollButton->setMaximumSize(QSize(24, 24));
-        d->leftScrollButton->setMaximumSize(QSize(24, 24));
+        size = QSize(24, 24);
     } else {
         radius = DStyle::pixelMetric(style(), DStyle::PM_FrameRadius);
-        QSize size = d->addButton->sizeHint();
-        d->addButton->setMaximumSize(size);
-        d->rightScrollButton->setMaximumSize(size);
-        d->leftScrollButton->setMaximumSize(size);
+        size = d->addButton->sizeHint();
     }
+    d->addButton->setMaximumSize(size);
+    d->rightScrollButton->setMaximumSize(size);
+    d->leftScrollButton->setMaximumSize(size);
 
     DStyle::setFrameRadius(d->rightScrollButton, radius);
     DStyle::setFrameRadius(d->leftScrollButton, radius);
     DStyle::setFrameRadius(d->addButton, radius);
+    update();
 }
 
 /*!
- * \~chinese \brief DTabBar::setTabLabelAlignment 设置tab标签文字对齐方式
- * \~chinese \param alignment 对齐
+  \brief 设置 tab 标签文字对齐方式.
+
+  \a alignment 对齐方式.
  */
 void DTabBar::setTabLabelAlignment(Qt::Alignment alignment)
 {
@@ -1894,7 +2173,9 @@ void DTabBar::setTabLabelAlignment(Qt::Alignment alignment)
 }
 
 /*!
- * \~chinese \brief 设置当前标签索引位置
+  \brief 设置当前标签索引位置.
+
+  \a index 标签索引.
  */
 void DTabBar::setCurrentIndex(int index)
 {
@@ -1902,7 +2183,9 @@ void DTabBar::setCurrentIndex(int index)
 }
 
 /*!
- * \~chinese \brief 设置新建标签按钮是否显示
+  \brief 设置新建标签按钮是否显示.
+
+  \a visibleAddButton 新建按钮是否可视.
  */
 void DTabBar::setVisibleAddButton(bool visibleAddButton)
 {
@@ -1910,18 +2193,12 @@ void DTabBar::setVisibleAddButton(bool visibleAddButton)
 
     d->visibleAddButton = visibleAddButton;
     d->addButton->setVisible(visibleAddButton);
-
-    if (visibleAddButton) {
-        d->addBtnL->changeSize(10, 0);
-        d->addBtnR->changeSize(10, 0);
-    } else {
-        d->addBtnL->changeSize(0, 0);
-        d->addBtnR->changeSize(0, 0);
-    }
 }
 
 /*!
- * \~chinese \brief 设置开始拖动距离
+  \brief 设置开始拖动距离.
+
+  \a startDragDistance 开始拖动的距离.
  */
 void DTabBar::setStartDragDistance(int startDragDistance)
 {
@@ -1929,7 +2206,9 @@ void DTabBar::setStartDragDistance(int startDragDistance)
 }
 
 /*!
- * \~chinese \brief 设置颜色
+  \brief 设置颜色.
+
+  \a maskColor 遮罩颜色.
  */
 void DTabBar::setMaskColor(QColor maskColor)
 {
@@ -2189,7 +2468,7 @@ QSize DTabBar::tabSizeHint(int index) const
     bool is_vertical = verticalTabs(dd->shape);
 
     if (is_vertical) {
-        size.setWidth(qMax(size.width(), d->width()));
+        size.setWidth(qMax(size.width(), dd->leftB->width()));
     } else {
         size.setHeight(qMax(size.height(), dd->leftB->height()));
     }
