@@ -12,6 +12,8 @@
 #include <QClipboard>
 #include <QKeySequence>
 
+#include <private/qtextedit_p.h>
+
 #include <DStyle>
 #include <DObjectPrivate>
 
@@ -38,8 +40,8 @@ public:
 };
 
 /*!
- * \~chinese \brief DTextEdit::DTextEdit 实现一个用于编辑和显示纯文本和富文本的控件
- * \~chinese \param parent
+  \brief DTextEdit::DTextEdit 实现一个用于编辑和显示纯文本和富文本的控件
+  \a parent
  */
 DTextEdit::DTextEdit(QWidget *parent)
     : QTextEdit(parent)
@@ -89,6 +91,34 @@ bool DTextEdit::event(QEvent *e)
         d->widgetButtom->setFixedHeight(frame_radius);
         d->widgetLeft->setFixedWidth(frame_radius);
         d->widgetRight->setFixedWidth(frame_radius);
+    } else if (e->type() == QEvent::InputMethodQuery && testAttribute(Qt::WA_InputMethodEnabled)) {
+        QInputMethodQueryEvent *query = static_cast<QInputMethodQueryEvent *>(e);
+        Qt::InputMethodQueries queries = query->queries();
+        for (uint i = 0; i < 32; ++i) {
+            // cppcheck-suppress shiftTooManyBitsSigned
+            Qt::InputMethodQuery property = (Qt::InputMethodQuery(uint(queries & (1<<i))));
+            if (property == Qt::ImCursorRectangle) {
+                QRect rc = cursorRect();
+                DStyleHelper dstyle(style());
+                int frame_radius = dstyle.pixelMetric(DStyle::PM_FrameRadius, nullptr, this);
+                // FIX bug-79676 setViewportMargins 会导致光标位置异常，此处调整回来吧
+                rc.adjust(frame_radius, 0, frame_radius, 0);
+                query->setValue(property, rc);
+                query->accept();
+                return true;
+            } else if (property == Qt::ImAnchorRectangle) {
+                QTextEditPrivate *d = reinterpret_cast<QTextEditPrivate *>(qGetPtrHelper(d_ptr));
+                QRect anchorRect = d->control->inputMethodQuery(Qt::ImAnchorRectangle, true).toRect();
+
+                DStyleHelper dstyle(style());
+                int frame_radius = dstyle.pixelMetric(DStyle::PM_FrameRadius, nullptr, this);
+
+                anchorRect.adjust(frame_radius, 0, frame_radius, 0);
+                query->setValue(Qt::ImAnchorRectangle, anchorRect);
+                query->accept();
+                return true;
+            }
+        }
     }
 
     return QTextEdit::event(e);
@@ -228,10 +258,9 @@ void DTextEdit::contextMenuEvent(QContextMenuEvent *e)
     menu->popup(e->globalPos());
 }
 
-
 /*!
- * \~chinese \brief DLineEdit::speechToTextIsEnabled
- * \~chinese \return true 显示语音听写菜单项 false不显示
+  \brief DLineEdit::speechToTextIsEnabled
+  \return true 显示语音听写菜单项 false不显示
  */
 bool DTextEdit::speechToTextIsEnabled() const
 {
@@ -240,8 +269,8 @@ bool DTextEdit::speechToTextIsEnabled() const
 }
 
 /*!
- * \~chinese \brief DLineEdit::setSpeechToTextEnabled 设置是否显示语音听写菜单项
- * \~chinese \param enable true显示 flase不显示
+  \brief DLineEdit::setSpeechToTextEnabled 设置是否显示语音听写菜单项
+  \a enable true显示 flase不显示
  */
 void DTextEdit::setSpeechToTextEnabled(bool enable)
 {
@@ -250,8 +279,8 @@ void DTextEdit::setSpeechToTextEnabled(bool enable)
 }
 
 /*!
- * \~chinese \brief DTextEdit::textToSpeechIsEnabled
- * \~chinese \return true 显示语音朗读菜单项 false不显示
+  \brief DTextEdit::textToSpeechIsEnabled
+  \return true 显示语音朗读菜单项 false不显示
  */
 bool DTextEdit::textToSpeechIsEnabled() const
 {
@@ -260,8 +289,8 @@ bool DTextEdit::textToSpeechIsEnabled() const
 }
 
 /*!
- * \~chinese \brief DTextEdit::setTextToSpeechEnabled 设置是否显示语音朗读菜单项
- * \~chinese \param enable true显示 flase不显示
+  \brief DTextEdit::setTextToSpeechEnabled 设置是否显示语音朗读菜单项
+  \a enable true显示 flase不显示
  */
 void DTextEdit::setTextToSpeechEnabled(bool enable)
 {
@@ -270,8 +299,8 @@ void DTextEdit::setTextToSpeechEnabled(bool enable)
 }
 
 /*!
- * \~chinese \brief DTextEdit::textToTranslateIsEnabled
- * \~chinese \return true 显示文本翻译菜单项 false不显示
+  \brief DTextEdit::textToTranslateIsEnabled
+  \return true 显示文本翻译菜单项 false不显示
  */
 bool DTextEdit::textToTranslateIsEnabled() const
 {
@@ -280,8 +309,8 @@ bool DTextEdit::textToTranslateIsEnabled() const
 }
 
 /*!
- * \~chinese \brief DTextEdit::setTextToTranslateEnabled 设置是否显示文本翻译菜单项
- * \~chinese \param enable true显示 flase不显示
+  \brief DTextEdit::setTextToTranslateEnabled 设置是否显示文本翻译菜单项
+  \a enable true显示 flase不显示
  */
 void DTextEdit::setTextToTranslateEnabled(bool enable)
 {
