@@ -18,8 +18,8 @@
 #ifndef DTICKEFFECT_H
 #define DTICKEFFECT_H
 
-#include "dtkwidget_global.h"
-#include "dobject.h"
+#include <dtkwidget_global.h>
+#include <DObject>
 
 #include <QGraphicsEffect>
 
