@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -20,7 +20,11 @@
 #include <QtMath>
 #include <QTimer>
 #include <QPainter>
+#include <QPainterPath>
 #include <QGraphicsDropShadowEffect>
+#include <QEvent>
+#include <QIcon>
+#include <QLinearGradient>
 
 #include <DObjectPrivate>
 #include <DSvgRenderer>
@@ -36,8 +40,8 @@ struct Pop {
     double size;
     double xSpeed;
     double ySpeed;
-    double xOffset;
-    double yOffset;
+    double xOffset = 0.0;
+    double yOffset = 0.0;
 };
 
 class DWaterProgressPrivate: public DTK_CORE_NAMESPACE::DObjectPrivate
@@ -58,36 +62,31 @@ public:
     QImage waterFrontImage;
     QImage waterBackImage;
     QString progressText;
-    QTimer *timer               = Q_NULLPTR;
+    QTimer *timer = Q_NULLPTR;
     QList<Pop> pops;
 
-    int     interval            = 33;
-    int     value;
+    int     interval = 33;
+    int     value = 0;
 
-    double  frontXOffset        = 0;
-    double  backXOffset         = 0;
+    double  frontXOffset = 0;
+    double  backXOffset = 0;
 
-    bool    textVisible         = true;
+    bool    textVisible = true;
 
     D_DECLARE_PUBLIC(DWaterProgress)
 };
 
 /*!
-    \~chinese \class DWaterProgress
-    \~chinese \brief 可以使用 DWaterProgress 类快速创建圆形容器内水位高低指示进度的动画控件。
+    \class Dtk::Widget::DWaterProgress
+    \inmodule dtkwidget
 
-    \~chinese \image html dwaterprogress.png
+    \brief 可以使用 DWaterProgress 类快速创建圆形容器内水位高低指示进度的动画控件.
+    \brief Use DWaterProgress to create an new water animation progress.
 
-    \~chinese 可以使用 DWaterProgress 类快速创建圆形容器内水位高低指示进度的动画控件。并提供了可选的是否显示进度文字的选项。
-*/
+    \image dwaterprogress.png
 
-/*!
-    \~english \class DWaterProgress
-    \~english \brief Use DWaterProgress to create an new water animation progress.
-
-    \~english \image html dwaterprogress.png
-
-    \~english Use DWaterProgress to create an new water animation progress. There is also an optional progress
+    可以使用 DWaterProgress 类快速创建圆形容器内水位高低指示进度的动画控件。并提供了可选的是否显示进度文字的选项。
+    Use DWaterProgress to create an new water animation progress. There is also an optional progress
     text can be set as visible via setTextVisible().
 */
 
@@ -111,8 +110,8 @@ DWaterProgress::~DWaterProgress()
 }
 
 /*!
- * \~english \brief get the current progress value
- * \~chinese \brief 当前进度值
+  \brief get the current progress value
+  \brief 当前进度值
  */
 int DWaterProgress::value() const
 {
@@ -121,8 +120,8 @@ int DWaterProgress::value() const
 }
 
 /*!
- * \~english \brief star water animation.
- * \~chinese \brief 开始水位动画
+  \brief star water animation.
+  \brief 开始水位动画
  */
 void DWaterProgress::start()
 {
@@ -131,8 +130,8 @@ void DWaterProgress::start()
 }
 
 /*!
- * \~english \brief stop water animation.
- * \~chinese \brief 停止水位动画
+  \brief stop water animation.
+  \brief 停止水位动画
  */
 void DWaterProgress::stop()
 {
@@ -141,8 +140,8 @@ void DWaterProgress::stop()
 }
 
 /*!
- * \~english \brief set the current progress value (range: 0~100)
- * \~chinese \brief 设置当前进度值，（范围 0~100）
+  \brief set the current progress \a value (range: 0~100)
+  \brief 设置当前进度值，（范围 0~100）
  */
 void DWaterProgress::setValue(int value)
 {
@@ -155,11 +154,11 @@ void DWaterProgress::setValue(int value)
 }
 
 /*!
- * \~english \brief set progress text visible or not
- * \~chinese \brief 设置是否显示进度
- *
- * \~english set the progress text value(like 50% when value is 50) visible.
- * \~chinese 设置进度文字是否显示，如值为 50 时显示 50% 。
+  \brief set progress text \a visible or not
+  \brief 设置是否显示进度
+  
+  set the progress text value(like 50% when value is 50) \a visible.
+  设置进度文字是否显示，如值为 50 时显示 50% 。
  */
 void DWaterProgress::setTextVisible(bool visible)
 {
@@ -174,6 +173,17 @@ void DWaterProgress::paintEvent(QPaintEvent *)
     d->paint(&p);
 }
 
+void DWaterProgress::changeEvent(QEvent *e)
+{
+    if (e->type() == QEvent::PaletteChange) {
+        D_D(DWaterProgress);
+        d->waterBackImage = QImage();
+        d->waterFrontImage = QImage();
+    }
+
+    return QWidget::changeEvent(e);
+}
+
 void DWaterProgressPrivate::resizePixmap(QSize sz)
 {
     // resize water;
@@ -182,19 +192,19 @@ void DWaterProgressPrivate::resizePixmap(QSize sz)
     auto waterSize = QSizeF(waterWidth, waterHeight).toSize();
 
     if (waterFrontImage.size() != waterSize) {
-        DSvgRenderer renderer(QString(":/images/light/images/water_front.svg"));
+        QIcon renderer = QIcon::fromTheme("water_front");
         QImage image(waterWidth, waterHeight, QImage::Format_ARGB32);
         image.fill(Qt::transparent);  // partly transparent red-ish background
         QPainter waterPainter(&image);
-        renderer.render(&waterPainter);
+        renderer.paint(&waterPainter, image.rect());
         waterFrontImage = image;
     }
     if (waterBackImage.size() != waterSize) {
-        DSvgRenderer renderer(QString(":/images/light/images/water_back.svg"));
+        QIcon renderer = QIcon::fromTheme("water_back");
         QImage image(waterWidth, waterHeight, QImage::Format_ARGB32);
         image.fill(Qt::transparent);  // partly transparent red-ish background
         QPainter waterPainter(&image);
-        renderer.render(&waterPainter);
+        renderer.paint(&waterPainter, image.rect());
         waterBackImage = image;
     }
 }
@@ -260,7 +270,7 @@ void DWaterProgressPrivate::initUI()
 void DWaterProgressPrivate::setValue(int v)
 {
     value = v;
-    progressText = QString("%1%").arg(v);
+    progressText = QString("%1").arg(v);
 }
 
 void DWaterProgressPrivate::paint(QPainter *p)
@@ -281,7 +291,21 @@ void DWaterProgressPrivate::paint(QPainter *p)
     QPainter waterPinter(&waterImage);
     waterPinter.setRenderHint(QPainter::Antialiasing);
     waterPinter.setCompositionMode(QPainter::CompositionMode_Source);
-    waterPinter.fillRect(waterImage.rect(), QColor(43, 146, 255, 255 * 3 / 10));
+
+    QPointF pointStart(sz.width() / 2, 0);
+    QPointF pointEnd(sz.width() / 2, sz.height());
+    QLinearGradient linear(pointStart, pointEnd);
+    QColor startColor("#1F08FF");
+    startColor.setAlphaF(1);
+    QColor endColor("#50FFF7");
+    endColor.setAlphaF(0.28);
+    linear.setColorAt(0, startColor);
+    linear.setColorAt(1, endColor);
+    linear.setSpread(QGradient::PadSpread);
+    waterPinter.setPen(Qt::NoPen);
+    waterPinter.setBrush(linear);
+    waterPinter.drawEllipse(waterImage.rect().center(), sz.width() / 2 + 1, sz.height() / 2  + 1);
+
     waterPinter.setCompositionMode(QPainter::CompositionMode_SourceOver);
     waterPinter.drawImage(static_cast<int>(backXOffset), yOffset, waterBackImage);
     waterPinter.drawImage(static_cast<int>(backXOffset) - waterBackImage.width(), yOffset, waterBackImage);
@@ -294,31 +318,65 @@ void DWaterProgressPrivate::paint(QPainter *p)
             QPainterPath popPath;
             popPath.addEllipse(pop.xOffset * sz.width() / 100, (100 - pop.yOffset) * sz.height() / 100,
                                pop.size * sz.width() / 100, pop.size * sz.height() / 100);
-            waterPinter.fillPath(popPath, QColor(77, 208, 255));
+            QColor color(255, 255, 255, 255 * 0.3);
+            waterPinter.fillPath(popPath, color);
         }
     }
 
-    double borderWidth = 2.0 * sz.width() / 100.0;
-    auto outRect = QRectF(0, 0, sz.width(), sz.height());
-    QPainterPath pathBorder;
-    auto factor = 0.5;
-    auto margin = QMarginsF(borderWidth * factor, borderWidth * factor,
-                            borderWidth * factor, borderWidth * factor);
-    pathBorder.addEllipse(outRect.marginsRemoved(margin));
-    waterPinter.strokePath(pathBorder, QPen(QColor(43, 146, 255, 255 * 7 / 10), borderWidth));
-    QPainterPath pathInnerBorder;
-    auto interFactor = 1.5;
-    auto innerMargin = QMarginsF(borderWidth * interFactor, borderWidth * interFactor,
-                                 borderWidth * interFactor, borderWidth * interFactor);
-    pathInnerBorder.addEllipse(outRect.marginsRemoved(innerMargin));
-    waterPinter.strokePath(pathInnerBorder, QPen(QColor(234, 242, 255, 255 * 5 / 10), borderWidth));
-
     if (textVisible) {
         auto font = waterPinter.font();
-        font.setPixelSize(sz.height() * 20 / 100);
-        waterPinter.setFont(font);
-        waterPinter.setPen(Qt::white);
-        waterPinter.drawText(rect, Qt::AlignCenter, progressText);
+
+        QRect rectValue;
+        QSize fontTextSize;
+        int actual_width;
+        int actual_height;
+        if (progressText == "100") {
+            font.setPixelSize(sz.height() * 35 / 100);
+            waterPinter.setFont(font);
+
+            fontTextSize = QFontMetrics(font).size(Qt::TextSingleLine | Qt::AlignCenter, progressText);
+            int design_width = sz.width() * 60 / 100;
+            int design_height = sz.height() * 35 / 100;
+            actual_width = qMax(fontTextSize.width(), design_width);
+            actual_height = qMax(fontTextSize.height(), design_height);
+
+            rectValue.setWidth(actual_width);
+            rectValue.setHeight(actual_height);
+            rectValue.moveCenter(rect.center().toPoint());
+            waterPinter.setPen(Qt::white);
+            waterPinter.drawText(rectValue, Qt::AlignCenter, progressText);
+
+        } else {
+            font.setPixelSize(sz.height() * 40 / 100);
+            waterPinter.setFont(font);
+
+            QFontMetrics numberFontMetrics(font);
+            fontTextSize = numberFontMetrics.size(Qt::TextSingleLine | Qt::AlignCenter, progressText);
+            int design_width = sz.width() * 45 / 100;
+            int design_height = sz.height() * 40 / 100;
+            actual_width = qMax(fontTextSize.width(), design_width);
+            actual_height = qMax(fontTextSize.height(), design_height);
+
+            rectValue.setWidth(actual_width);
+            rectValue.setHeight(actual_height);
+            rectValue.moveCenter(rect.center().toPoint());
+            rectValue.moveLeft(rect.left() + rect.width() * 0.45 * 0.5);
+
+            waterPinter.setPen(Qt::white);
+            waterPinter.drawText(rectValue, Qt::AlignCenter, progressText);
+            font.setPixelSize(font.pixelSize() / 2);
+            waterPinter.setFont(font);
+
+            QFontMetrics ratioFontMetrics(font);
+            design_height = rect.height() * 20 / 100;
+            actual_height = qMax(ratioFontMetrics.height(), design_height);
+            int descent_diff = numberFontMetrics.descent() - ratioFontMetrics.descent();
+
+            QRect rectPerent(QPoint(rectValue.right(), rectValue.bottom() - descent_diff - actual_height),
+                             QPoint(rectValue.right() + rect.width() * 20 / 100, rectValue.bottom() - descent_diff));
+
+            waterPinter.drawText(rectPerent, Qt::AlignCenter, "%");
+        }
     }
     waterPinter.end();
 
