@@ -21,7 +21,7 @@
 #include <QPointer>
 #include <QPushButton>
 #include <QSpacerItem>
-#include "ddialog.h"
+#include <DDialog>
 #include "dabstractdialogprivate_p.h"
 
 QT_BEGIN_NAMESPACE
@@ -55,6 +55,7 @@ private:
     DTitlebar   *titleBar = nullptr;
     QHBoxLayout *iconLayout;
     QVBoxLayout *contentLayout;
+    QWidget *contentWidget = nullptr;
     QHBoxLayout *buttonLayout;
     const QScreen *targetScreen = nullptr;
     QSpacerItem *spacer = nullptr;
