@@ -19,7 +19,7 @@
 #ifndef DSWITCHBUTTON_P_H
 #define DSWITCHBUTTON_P_H
 
-#include "dswitchbutton.h"
+#include <DSwitchButton>
 
 #include <DObjectPrivate>
 
@@ -39,8 +39,8 @@ public:
     QColor disabledBackground = qRgba(207, 214, 230, 255);
     QColor checkedBackground =  qRgba(44, 167, 248, 255);
 
-    double animationStartValue;
-    double animationEndValue;
+    double animationStartValue = 0.0;
+    double animationEndValue = 0.0;
 
 public:
     D_DECLARE_PUBLIC(DSwitchButton)
