@@ -33,7 +33,7 @@
 #include <DSuggestButton>
 #include <DPushButton>
 #include <DFontSizeManager>
-#include <DFrame>
+#include <DBackgroundGroup>
 
 #include "dsettingswidgetfactory.h"
 
@@ -44,20 +44,20 @@ DWIDGET_BEGIN_NAMESPACE
 class ContentPrivate
 {
 public:
-    ContentPrivate(Content *parent) : q_ptr(parent)
+    ContentPrivate(Content *parent)
+        : q_ptr(parent)
     {
         widgetFactory = new DSettingsWidgetFactory(parent);
     }
 
+    QScrollArea *contentArea = nullptr;
+    QWidget *contentFrame = nullptr;
+    QVBoxLayout *contentLayout = nullptr;
 
-    QScrollArea         *contentArea;
-    QWidget             *contentFrame;
-    QFormLayout         *contentLayout;
+    QMap<QString, QWidget *> titles = {};
+    QList<QWidget *> sortTitles = {};
 
-    QMap<QString, QWidget *> titles;
-    QList<QWidget *> sortTitles;
-
-    DSettingsWidgetFactory       *widgetFactory;
+    DSettingsWidgetFactory *widgetFactory = nullptr;
 
     Content *q_ptr;
     Q_DECLARE_PUBLIC(Content)
@@ -94,10 +94,8 @@ Content::Content(QWidget *parent)
     d->contentFrame = new QWidget(this);
     d->contentFrame->setObjectName("SettingsContent");
     d->contentFrame->setAccessibleName("ContentSettingsFrame");
-    d->contentLayout = new QFormLayout(d->contentFrame);
-    d->contentLayout->setRowWrapPolicy(QFormLayout::DontWrapRows);
-    d->contentLayout->setLabelAlignment(Qt::AlignLeft);
-    d->contentLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
+    d->contentLayout = new QVBoxLayout(d->contentFrame);
+    d->contentLayout->setAlignment(Qt::AlignLeft);
     d->contentLayout->setContentsMargins(0, 0, 10, 0);
     layout->addWidget(d->contentArea);
 
@@ -106,16 +104,27 @@ Content::Content(QWidget *parent)
     connect(d->contentArea->verticalScrollBar(), &QScrollBar::valueChanged,
     this, [ = ](int value) {
         Q_D(Content);
+
+        // 当前显示的Title才参与滚动条的计算
+        QList<QWidget *> visableSortTitles;
+        for (auto idx = 0; idx < d->sortTitles.length(); ++idx) {
+            auto title = d->sortTitles[idx];
+            if (title->isVisible())
+                visableSortTitles.push_back(title);
+        }
+        if (visableSortTitles.empty())
+            return;
+
+        auto currentTitle = visableSortTitles.first();
         auto viewHeight = d->contentArea->height();
-        auto currentTitle = d->sortTitles.first();
 
         QList<QWidget *> visableTitleList;
 
-        for (auto idx = 0; idx < d->sortTitles.length(); ++idx) {
-            auto title = d->sortTitles[idx];
+        for (auto idx = 0; idx < visableSortTitles.length(); ++idx) {
+            auto title = visableSortTitles[idx];
             if (title->y() <= value) {
-                if (idx < d->sortTitles.length() - 1) {
-                    auto nextTitle = d->sortTitles[idx + 1];
+                if (idx < visableSortTitles.length() - 1) {
+                    auto nextTitle = visableSortTitles[idx + 1];
                     if (nextTitle->y() >= value) {
                         visableTitleList.push_back(title);
                     }
@@ -126,7 +135,7 @@ Content::Content(QWidget *parent)
         }
 
         if (!visableTitleList.isEmpty()) {
-            auto lastTitle = d->sortTitles.last();
+            auto lastTitle = visableSortTitles.last();
             if (value + viewHeight - 180 >= lastTitle->y()) {
                 currentTitle = visableTitleList.last();
             } else {
@@ -134,10 +143,10 @@ Content::Content(QWidget *parent)
             }
         }
 
-        if (value >= d->sortTitles.last()->y())
-            currentTitle = d->sortTitles.last();
-        if (value <= d->sortTitles.first()->y())
-            currentTitle = d->sortTitles.first();
+        if (value >= visableSortTitles.last()->y())
+            currentTitle = visableSortTitles.last();
+        if (value <= visableSortTitles.first()->y())
+            currentTitle = visableSortTitles.first();
 
         if (currentTitle) {
             Q_EMIT scrollToGroup(currentTitle->property("key").toString());
@@ -169,23 +178,17 @@ void Content::setGroupVisible(const QString &key, bool visible)
 {
     Q_D(Content);
 
-    if (!d->titles.contains(key))
-        return;
-
-    auto title = d->titles.value(key);
-    title->setVisible(visible);
-
+    QSet<QString> keys = {key}; // 需要改变visible的key集合
     for (QObject *obj : d->contentFrame->children()) {
-        if (obj->property("_d_dtk_group_key").toString() == key) {
-            if (ContentTitle *title = qobject_cast<ContentTitle *>(obj)) {
-                const QString &key = title->property("key").toString();
+        auto parentKey = obj->property("_d_dtk_group_key").toString();
+        auto currKey = obj->property("key").toString();
 
-                if (d->titles.contains(key)) {
-                    setGroupVisible(key, visible);
-                    continue;
-                }
-            }
+        // 若父组或者当前组为需要改变visible,则加入到keys集合中
+        if (parentKey == key || currKey == key) {
+            keys << currKey;
+        }
 
+        if (keys.contains(currKey)) {
             if (QWidget *w = qobject_cast<QWidget *>(obj)) {
                 if (!visible || w->parentWidget()) // 无父控件时禁止其显示
                     w->setVisible(visible);
@@ -235,7 +238,7 @@ void Content::updateSettings(const QByteArray &translateContext, QPointer<DTK_CO
         widTile->setAccessibleName(QString("ContentWidTileFor").append(groupKey));
         QHBoxLayout *hLayTile = new QHBoxLayout(widTile);
         hLayTile->addWidget(title);
-        d->contentLayout->setWidget(d->contentLayout->rowCount(), QFormLayout::SpanningRole, widTile);
+        d->contentLayout->addWidget(widTile);
 
         d->sortTitles.push_back(widTile);
         d->titles.insert(groupKey, widTile);
@@ -264,17 +267,29 @@ void Content::updateSettings(const QByteArray &translateContext, QPointer<DTK_CO
                 hLay->setContentsMargins(10, 0, 0, 0);
                 hLay->addWidget(title);
 
-                d->contentLayout->setWidget(d->contentLayout->rowCount(), QFormLayout::LabelRole, wid);
+                d->contentLayout->addWidget(wid);
 
                 d->sortTitles.push_back(wid);
                 d->titles.insert(subgroup->key(), wid);
             }
 
+            QVBoxLayout *bgGpLayout = new QVBoxLayout;
+            DBackgroundGroup *bgGroup = new DBackgroundGroup(bgGpLayout);
+            bgGroup->setProperty("key", subgroup->key());
+            bgGroup->setProperty("_d_dtk_group_key", current_groupKey);
+            bgGroup->setItemSpacing(1);
+            bgGroup->setItemMargins(QMargins(0, 0, 0, 0));
+            bgGroup->setBackgroundRole(QPalette::Window);
+            d->contentLayout->addWidget(bgGroup);
+
             for (auto option : subgroup->childOptions()) {
                 if (option->isHidden()) {
                     continue;
                 }
 
+                QWidget *wrapperWidget = new QWidget();
+                QHBoxLayout *hLay = new QHBoxLayout(wrapperWidget);
+                hLay->setContentsMargins(10, 6, 10, 6);
                 auto widget = d->widgetFactory->createItem(translateContext, option);
 
                 // 先尝试创建item
@@ -284,16 +299,17 @@ void Content::updateSettings(const QByteArray &translateContext, QPointer<DTK_CO
                             label->setBuddy(widget.second);
                     }
 
-                    DFrame *frame = new DFrame();
-                    frame->setLineWidth(0);
-                    frame->setBackgroundRole(DPalette::ItemBackground);
-                    QHBoxLayout *hLay = new QHBoxLayout(frame);
-                    QMargins margins = hLay->contentsMargins();
-                    hLay->setContentsMargins(15, margins.top(), margins.right(), margins.bottom());
-                    hLay->addWidget(widget.first, 2);
-                    hLay->addWidget(widget.second, 3);
-                    d->contentLayout->addRow(frame);
-                    frame->setAccessibleName(QString("ContentItemFrameAtRow").append(QString::number(d->contentLayout->count())));
+                    if (widget.first) {
+                        QWidget *container = new QWidget;
+                        QHBoxLayout *hLayout = new QHBoxLayout(container);
+                        hLayout->addWidget(widget.first);
+                        hLayout->addStretch(1);
+                        hLay->addWidget(container, 2);
+                    }
+                    if (widget.second) {
+                        hLay->addWidget(widget.second, 3);
+                    }
+                    wrapperWidget->setAccessibleName(QString("CustomWidgetAtContentRow%1BackgroundRow%2").arg(d->contentLayout->count()).arg(bgGpLayout->count()));
 
                     if (widget.first) {
                         widget.first->setProperty("_d_dtk_group_key", current_subGroupKey);
@@ -307,21 +323,15 @@ void Content::updateSettings(const QByteArray &translateContext, QPointer<DTK_CO
 
                     if (widget) {
                         widget->setProperty("_d_dtk_group_key", current_subGroupKey);
-                        DFrame *frame = new DFrame();
-                        frame->setLineWidth(0);
-                        frame->setBackgroundRole(DPalette::ItemBackground);
-                        QHBoxLayout *hLay = new QHBoxLayout(frame);
-                        QMargins margins = hLay->contentsMargins();
-                        hLay->setContentsMargins(15, margins.top(), margins.right(), margins.bottom());
                         hLay->addWidget(widget);
-                        d->contentLayout->addRow(frame);
-                        frame->setAccessibleName(QString("ContentItemWidgetAtRow").append(QString::number(d->contentLayout->count())));
+                        wrapperWidget->setAccessibleName(QString("DefaultWidgetAtContentRow%1BackgroundRow%2").arg(d->contentLayout->count()).arg(bgGpLayout->count()));
                     }
                 }
+                bgGpLayout->addWidget(wrapperWidget);
             }
         }
         QSpacerItem *spaceItem = new QSpacerItem(0, 20,QSizePolicy::Minimum,QSizePolicy::Expanding);
-        d->contentLayout->setItem(d->contentLayout->rowCount(), QFormLayout::LabelRole, spaceItem);
+        d->contentLayout->addItem(spaceItem);
     }
 
     QWidget *box = new QWidget();
@@ -336,7 +346,7 @@ void Content::updateSettings(const QByteArray &translateContext, QPointer<DTK_CO
     box->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     box->setAccessibleName("ContentBottomWidget");
 
-    d->contentLayout->setWidget(d->contentLayout->rowCount(), QFormLayout::SpanningRole, box);
+    d->contentLayout->addWidget(box);
 
     connect(resetBt, &QPushButton::released,
     this, [ = ]() {
