@@ -2,7 +2,7 @@
  * Copyright (C) 2016 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,14 +11,14 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #pragma once
 
 #include <QScopedPointer>
-#include <QWidget>
+#include <QLabel>
 
 class ContentTitlePrivate;
 class ContentTitle : public QWidget
@@ -28,7 +28,8 @@ public:
     explicit ContentTitle(QWidget *parent = 0);
     ~ContentTitle();
 
-Q_SIGNALS:
+    void setSpacing(int width);
+    QLabel *label() const;
 
 public Q_SLOTS:
     void setTitle(const QString &title);
