@@ -26,7 +26,7 @@
 #include <DSettings>
 #include <DSettingsGroup>
 #include <DListView>
-#include <DApplicationHelper>
+#include <DPaletteHelper>
 
 #include "navigationdelegate.h"
 
@@ -48,6 +48,25 @@ public:
         return QModelIndex();
     }
 
+    // 返回所有符合条件的key集合, e.g: key: abc, 可返回{abc.dc, abc}, 过滤掉{abcd}
+    QList<QModelIndex> indexesOfGroup(const QString &key) const
+    {
+        static const QChar SplitChar = '.'; // group之间的key以'.'分割连接组成实际的key值
+        QList<QModelIndex> res;
+        for (int i = 0; i < navbarModel->rowCount(); ++i) {
+            auto index = navbarModel->index(i, 0);
+            const auto& navKey = index.data(NavigationDelegate::NavKeyRole).toString();
+            if (navKey.startsWith(key)) {
+                const auto& remainderKey = navKey.mid(key.size());
+                if (remainderKey.isEmpty() || remainderKey.at(0) == SplitChar) {
+                    res.append(index);
+                }
+            }
+        }
+
+        return res;
+    }
+
     DListView           *navbar         = nullptr;
     QStandardItemModel  *navbarModel    = nullptr;
 
@@ -72,9 +91,9 @@ Navigation::Navigation(QWidget *parent) :
     d->navbar->setContentsMargins(0, 0, 0, 0);
     d->navbar->setAutoFillBackground(true);
     d->navbar->setViewportMargins(10, 0, 10, 0);
-    DPalette pa = DApplicationHelper::instance()->palette(d->navbar);
+    DPalette pa = DPaletteHelper::instance()->palette(d->navbar);
     pa.setBrush(DPalette::ItemBackground, Qt::transparent);
-    DApplicationHelper::instance()->setPalette(d->navbar, pa);
+    DPaletteHelper::instance()->setPalette(d->navbar, pa);
 
     d->navbar->setSelectionMode(QListView::SingleSelection);
     d->navbar->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -114,9 +133,7 @@ void Navigation::setGroupVisible(const QString &key, bool visible)
 {
     Q_D(Navigation);
 
-    const QModelIndex &index = d->indexOfGroup(key);
-
-    if (index.isValid()) {
+    for (const auto& index : d->indexesOfGroup(key)) {
         d->navbar->setRowHidden(index.row(), !visible);
     }
 }
@@ -144,12 +161,7 @@ void Navigation::updateSettings(const QByteArray &translateContext, QPointer<DTK
         auto item = new QStandardItem;
         auto trName = translateContext.isEmpty() ? QObject::tr(group->name().toStdString().c_str())
                                                  : qApp->translate(translateContext.constData(), group->name().toStdString().c_str());
-//        qDebug() << settings->group(groupKey)->name() << trName;
-//        QFont font(item->data(Qt::FontRole).value<QFont>());
-//        QFontMetrics fm(font);
-//        int width = fm.width(trName);
-//        qDebug() << ">>>>>>>>>>> " << font << trName << width;
-
+        item->setToolTip(trName);
         item->setData(trName, Qt::DisplayRole);
         item->setData(NavigationDelegate::Level1, NavigationDelegate::NavLevelRole);
         item->setData(groupKey, NavigationDelegate::NavKeyRole);
@@ -167,11 +179,7 @@ void Navigation::updateSettings(const QByteArray &translateContext, QPointer<DTK
             auto item = new QStandardItem;
             auto trName = translateContext.isEmpty() ? QObject::tr(subgroup->name().toStdString().c_str())
                                                      : qApp->translate(translateContext.constData(), subgroup->name().toStdString().c_str());
-//            qDebug() << subgroup->name() << trName;
-//            QFont font(item->data(Qt::FontRole).value<QFont>());
-//            QFontMetrics fm(font);
-//            int width = fm.width(trName);
-//            qDebug() << "<<<<<<<<<<<< " << font << trName << width;
+            item->setToolTip(trName);
             item->setData(trName, Qt::DisplayRole);
             item->setData(NavigationDelegate::Level2, NavigationDelegate::NavLevelRole);
             item->setData(subgroup->key(), NavigationDelegate::NavKeyRole);
